@@ -13,12 +13,14 @@
 TestDataSet::TestDataSet() {
     m = MothurOut::getInstance();
     gMap = NULL;
+    testDir = "/Users/sarahwestcott/Desktop/mothur/TestMothur/TestFiles/";
 }
 /***********************************************************************/
 void TestDataSet::createCountTable() {
     fillGroup();
     fillNames();
     ct = new CountTable();
+    
     for (map<string, string>::iterator itNameMap = nameMap.begin(); itNameMap !=nameMap.end(); itNameMap++) {
         string firstCol = itNameMap->first;
         string secondCol = itNameMap->second;
@@ -57,14 +59,63 @@ void TestDataSet::createCountTable() {
 /***********************************************************************/
 
 vector<string> TestDataSet::getSubsetFNGFiles() {
-    vector<string> filenames; filenames.push_back("/Users/sarahwestcott/Desktop/mothur/TestMothur/TestFiles/tempSeqs.txt"); filenames.push_back("/Users/sarahwestcott/Desktop/mothur/TestMothur/TestFiles/tempNames.txt"); filenames.push_back("/Users/sarahwestcott/Desktop/mothur/TestMothur/TestFiles/tempGroup.txt");
+    vector<string> filenames;
+    filenames.push_back(testDir+"test.fasta");
+    filenames.push_back(testDir+"test.names");
+    filenames.push_back(testDir+"test.groups");
+    
+    return filenames;
+}
+/***********************************************************************/
+
+string TestDataSet::getCountTableFile() {
+    return testDir+"test.count_table";
+}
+/***********************************************************************/
+
+string TestDataSet::getSharedFile() {
+    return testDir+"test.opti_mcc.shared";
+}
+/***********************************************************************/
+
+string TestDataSet::getRelabundFile() {
+    return testDir+"test.opti_mcc.relabund";
+}
+
+/***********************************************************************/
+
+vector<string> TestDataSet::getOptiRefFiles() {
+    vector<string> filenames;
+    filenames.push_back(testDir+"silva.v4.unique.fasta");
+    filenames.push_back(testDir+"silva.v4.count_table");
+    filenames.push_back(testDir+"silva.v4.unique.dist");
+    filenames.push_back(testDir+"silva.v4.unique.phylip.dist");
+    filenames.push_back(testDir+"silva.v4.unique.opti_mcc.list");
+    filenames.push_back(testDir+"test.fit.dist");
+    
+    return filenames;
+}
+
+/***********************************************************************/
+
+vector<string> TestDataSet::getOligosFiles() {
+    vector<string> filenames;
+    filenames.push_back(testDir+"GQY1XT001.oligos"); //single
+    filenames.push_back(testDir+"Undetermined.oligos"); //paired
+    filenames.push_back(testDir+"bo.oligos"); //index "NONE"
+    filenames.push_back(testDir+"comboNames.oligos"); //named primers and named barcodes
     
     return filenames;
 }
 /***********************************************************************/
 string TestDataSet::getSubsetFNGDistFile() {
     
-    return "/Users/sarahwestcott/Desktop/mothur/TestMothur/TestFiles/tempSeqs.dist";
+    return (testDir+"test.dist");
+}
+/***********************************************************************/
+string TestDataSet::getSubsetFNGPhylipDistFile() {
+    
+    return (testDir+"test.phylip.dist");
 }
 /***********************************************************************/
 void TestDataSet::fillSeqs() {
@@ -72,7 +123,7 @@ void TestDataSet::fillSeqs() {
     
     //read info from stable file
     //string testfile = m->getTestFilePath() + "testFile.fasta";
-     string testfile ="/Users/sarahwestcott/Desktop/mothur/TestMothur/TestFiles/testFile.fasta";
+     string testfile = testDir+"test.fasta";
     
     ifstream in;
     util.openInputFile(testfile, in);
@@ -90,7 +141,7 @@ void TestDataSet::fillNames() {
     nameMap.clear();
     
     //read info from stable file
-    string testfile = "/Users/sarahwestcott/Desktop/mothur/TestMothur/TestFiles/testFile.names";
+    string testfile = testDir+"test.names";
     util.readNames(testfile, nameMap);
 }
 /***********************************************************************/
@@ -98,7 +149,7 @@ void TestDataSet::fillGroup() {
     if (gMap != NULL) { delete gMap; gMap = NULL; }
     
     //read info from stable file
-    string testfile = "/Users/sarahwestcott/Desktop/mothur/TestMothur/TestFiles/testFile.groups";
+    string testfile = testDir+"test.groups";
     
     gMap = new GroupMap();
     gMap->readMap(testfile);
@@ -109,10 +160,11 @@ void TestDataSet::fillLookup() {
     lookup.clear();
     
     //read info from stable file
-    string testfile = "/Users/sarahwestcott/Desktop/mothur/TestMothur/TestFiles/testFile.opti_mcc.shared";
+    string testfile = testDir+"test.opti_mcc.shared";
 
-    InputData input(testfile, "sharedfile");
-    lookup = input.getSharedRAbundVectors();
+    InputData input(testfile, "sharedfile", nullVector);
+    SharedRAbundVectors* shared = input.getSharedRAbundVectors();
+    lookup = shared->getSharedRAbundVectors();
 }
 /***********************************************************************/
 
