@@ -12,8 +12,9 @@
 #include "sequence.hpp"
 #include "counttable.h"
 #include "groupmap.h"
-#include "sharedrabundvector.h"
+#include "sharedrabundvector.hpp"
 #include "fastqdataset.h"
+#include "utils.hpp"
 
 class TestDataSet  {
     
@@ -25,17 +26,27 @@ public:
     GroupMap* getGroupMap()                     { fillGroup(); return gMap;             }
     CountTable* getCountTable()                 { createCountTable(); return ct;        }
     vector<SharedRAbundVector*> getLookup()     { fillLookup(); return lookup;          }
+    
     vector<string> getSubsetFNGFiles();  //Fasta, name, group returned - containing 100 seqs
     string getSubsetFNGDistFile();
+    string getSubsetFNGPhylipDistFile();
+    vector<string> getOptiRefFiles(); //fasta, count, column, phylip, list, betweendist
+    vector<string> getOligosFiles(); //single, paired, indexes, comboNamesTest
+    string getSharedFile(); //shared
+    string getRelabundFile(); //relabund
+    string getCountTableFile(); //count
     
 private:
     MothurOut* m;
+    Utils util;
     TestFastqDataSet fastqData;
     vector<Sequence> seqs;
     map<string, string> nameMap;
     CountTable* ct;
     GroupMap* gMap;
     vector<SharedRAbundVector*> lookup;
+    string testDir;
+    
     void fillNames();
     void fillSeqs();
     void fillGroup();
