@@ -10,7 +10,8 @@
 #define testtrimoligos_hpp
 
 #include "trimoligos.h"
-
+#include "gtest/gtest.h"
+#include "fakeoligos.h"
 
 class TestTrimOligos : public TrimOligos {
     
@@ -20,11 +21,8 @@ public:
     TestTrimOligos();
     ~TestTrimOligos();
     
-    MothurOut* m;
+    FakeOligos oligos;
     
-    Sequence* fseq;
-    //using TrimOligos::compareDNASeq(string, string);
-    //using TrimOligos::countDiffs(string, string);
     
 };
 
