@@ -9,7 +9,7 @@
 #ifndef fn_hpp
 #define fn_hpp
 
-#include <calculator.h>
+#include "calculator.h"
 
 /***********************************************************************/
 
@@ -17,7 +17,7 @@ class FN : public ClusterMetric  {
     
 public:
     FN() : ClusterMetric("fn") {};
-    double getValue( long long tp,  long long tn,  long long fp,  long long fn);
+    double getValue(double tp,  double tn,  double fp,  double fn);
     string getCitation() { return "http://www.mothur.org/wiki/FN"; }
     
 private:
