@@ -10,22 +10,23 @@
 #define lnabundace_hpp
 
 #include "diversityutils.hpp"
+#include "diversitycalc.h"
 
 /***********************************************************************/
 
-class LNAbundance   {
+class LNAbundance : public DiversityCalculator  {
     
 public:
     
-    LNAbundance() { m = MothurOut::getInstance(); }
+    LNAbundance();
     
-    vector<double> getValues(SAbundVector* rank, vector<mcmcSample>& sampling);
+    vector<double> getValues(int mr, vector<mcmcSample>& sampling);
     
-    bool requiresSample() { return true; }
+    string getTag() { return "ln"; }
     
 private:
-    Utils util;
-    MothurOut* m;
+    
+    
     
 };
 
