@@ -16,8 +16,8 @@ EstOutput MemEuclidean::getValues(vector<SharedRAbundVector*> shared) {
 		
 		double sum = 0.0;
 		for (int i = 0; i < shared[0]->getNumBins(); i++) {
-			int A = shared[0]->getAbundance(i);
-			int B = shared[1]->getAbundance(i);
+			int A = shared[0]->get(i);
+			int B = shared[1]->get(i);
 			
 			if (A > 0) { A = 1; }
 			if (B > 0) { B = 1; }
