@@ -110,8 +110,8 @@ void SharedChao1::initialTree(int n) {
 	
 		//initialize leaf values
 		for (int i = 0; i < numLeaves; i++) {
-			f1leaves[i] = new IntNode(0, 0, NULL, NULL);
-			f2leaves[i] = new IntNode(0, 0, NULL, NULL);
+			f1leaves[i] = new IntNode(0, 0, nullptr, nullptr);
+			f2leaves[i] = new IntNode(0, 0, nullptr, nullptr);
 		}
 		
 		//set pointers to children
@@ -138,7 +138,7 @@ void SharedChao1::initialTree(int n) {
 		setCoef(f2root, 0);
 	}
 	catch(exception& e) {
-		if ((toString(e.what()) == "vector::_M_fill_insert") || (toString(e.what()) == "St9bad_alloc")) { m->mothurOut("You are using " + toString(n) + " groups which creates 2^" + toString(n+1) + " nodes. Try reducing the number of groups you selected. "); m->mothurOutEndLine(); exit(1); }
+		if ((toString(e.what()) == "vector::_M_fill_insert") || (toString(e.what()) == "St9bad_alloc")) { m->mothurOut("You are using " + toString(n) + " groups which creates 2^" + toString(n+1) + " nodes. Try reducing the number of groups you selected. \n");  exit(1); }
 		m->errorOut(e, "SharedChao1", "initialTree");
 		exit(1);
 	}
@@ -204,7 +204,7 @@ void SharedChao1::updateBranchf2(IntNode* node, vector<int> bin, int index) {
 /***********************************************************************/
 void SharedChao1::setCoef(IntNode* node, int coef) {
 	try {
-		if (node->left != NULL) {
+		if (node->left != nullptr) {
 			setCoef(node->left, coef+1);
 			setCoef(node->right, coef);
 		}else {
@@ -222,10 +222,10 @@ void SharedChao1::setCoef(IntNode* node, int coef) {
 //for debugging purposes
 void SharedChao1::printTree() {
 	
-	m->mothurOut("F1 leaves"); m->mothurOutEndLine();
+	m->mothurOut("F1 leaves\n"); 
 	printBranch(f1root);
 	
-	m->mothurOut("F2 leaves"); m->mothurOutEndLine();
+	m->mothurOut("F2 leaves\n"); 
 	printBranch(f2root);
 
 
@@ -235,12 +235,12 @@ void SharedChao1::printBranch(IntNode* node) {
 	try {
 		
 		// you are not a leaf
-		if (node->left != NULL) {
+		if (node->left != nullptr) {
 			printBranch(node->left);
 			printBranch(node->right);
 		}else { //you are a leaf
-			m->mothurOut(toString(node->lvalue)); m->mothurOutEndLine();
-			m->mothurOut(toString(node->rvalue)); m->mothurOutEndLine();
+			m->mothurOut(toString(node->lvalue)+"\n"); 
+			m->mothurOut(toString(node->rvalue)+"\n");
 		}
 		
 	}
