@@ -26,11 +26,11 @@ EstOutput KulczynskiCody::getValues(vector<SharedRAbundVector*> shared) {
 			tempA = shared[0]->get(i);
 			tempB = shared[1]->get(i);
 			
-			if (tempA != 0) { S1++; }
-			if (tempB != 0) { S2++; } 
+			if (!util.isEqual(tempA, 0)) { S1++; }
+			if (!util.isEqual(tempB, 0)) { S2++; }
 
 			//they are shared
-			if ((tempA != 0) && (tempB != 0)) {	S12++; }
+			if (!util.isEqual(tempA, 0) && !util.isEqual(tempB, 0)) {	S12++; }
 		}
 		
 		data[0] = 1.0 - 0.5 * ((S12 / (float)S1) + (S12 / (float)S2));
