@@ -11,7 +11,7 @@
  */
 
 #include "mothurchimera.h"
-#include "dist.h"
+#include "calculator.h"
 #include "decalc.h"
 
 /***********************************************************/
@@ -24,7 +24,7 @@
 class Pintail : public MothurChimera {
 	
 	public:
-		Pintail(string, string, bool, int, string, string, string, int, int, string); //fastafile, templatefile, filter, processors, mask, conservation, quantile, window, increment, outputDir)	
+		Pintail(string, string, bool, string, string, string, int, int, string, string); //fastafile, templatefile, filter, processors, mask, conservation, quantile, window, increment, outputDir, version)
 		~Pintail();
 		
 		int getChimeras(Sequence*);
@@ -35,12 +35,11 @@ class Pintail : public MothurChimera {
 
 	private:
 	
-		Dist* distcalculator;
+		DistCalc* distcalculator;
 		DeCalculator* decalc;
 		int iters, window, increment, processors;
 		string fastafile, quanfile, consfile;
 		
-		vector<linePair*> templateLines;
 		Sequence* querySeq;
 				
 		Sequence* bestfit;  //closest match to query in template
@@ -70,10 +69,8 @@ class Pintail : public MothurChimera {
 		vector<float> readFreq();
 		Sequence* findPairs(Sequence*);
 			
-		void createProcessesQuan();
-		int doPrep();
+		int doPrep(string);
 		void printQuanFile(string, string);
-		
 };
 
 /***********************************************************/
