@@ -8,9 +8,10 @@
  */
 
 #include "chimeraslayercommand.h"
-#include "deconvolutecommand.h"
+#include "uniqueseqscommand.h"
 #include "sequenceparser.h"
 #include "counttable.h"
+#include "removeseqscommand.h"
 
 //**********************************************************************************************************************
 vector<string> ChimeraSlayerCommand::setParameters(){	
@@ -28,7 +29,6 @@ vector<string> ChimeraSlayerCommand::setParameters(){
 		CommandParameter pmincov("mincov", "Number", "", "70", "", "", "","",false,false); parameters.push_back(pmincov);
 		CommandParameter pminsnp("minsnp", "Number", "", "10", "", "", "","",false,false); parameters.push_back(pminsnp);
 		CommandParameter pminbs("minbs", "Number", "", "90", "", "", "","",false,false); parameters.push_back(pminbs);
-		CommandParameter psearch("search", "Multiple", "kmer-blast", "blast", "", "", "","",false,false); parameters.push_back(psearch);
 		CommandParameter prealign("realign", "Boolean", "", "T", "", "", "","",false,false); parameters.push_back(prealign);
 		CommandParameter ptrim("trim", "Boolean", "", "F", "", "", "","fasta",false,false); parameters.push_back(ptrim);
 		CommandParameter psplit("split", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(psplit);
@@ -36,9 +36,9 @@ vector<string> ChimeraSlayerCommand::setParameters(){
 		CommandParameter piters("iters", "Number", "", "1000", "", "", "","",false,false); parameters.push_back(piters);
 		CommandParameter pdivergence("divergence", "Number", "", "1.007", "", "", "","",false,false); parameters.push_back(pdivergence);
         CommandParameter pdups("dereplicate", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(pdups);
-		CommandParameter pparents("parents", "Number", "", "3", "", "", "","",false,false); parameters.push_back(pparents);
+        CommandParameter premovechimeras("removechimeras", "Boolean", "", "t", "", "", "","alns",false,false); parameters.push_back(premovechimeras);
+        CommandParameter pparents("parents", "Number", "", "3", "", "", "","",false,false); parameters.push_back(pparents);
 		CommandParameter pincrement("increment", "Number", "", "5", "", "", "","",false,false); parameters.push_back(pincrement);
-		CommandParameter pblastlocation("blastlocation", "String", "", "", "", "", "","",false,false); parameters.push_back(pblastlocation);
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
@@ -66,7 +66,7 @@ string ChimeraSlayerCommand::getHelpString(){
 		string helpString = "";
 		helpString += "The chimera.slayer command reads a fastafile and referencefile and outputs potentially chimeric sequences.\n";
 		helpString += "This command was modeled after the chimeraSlayer written by the Broad Institute.\n";
-		helpString += "The chimera.slayer command parameters are fasta, name, group, template, processors, dereplicate, trim, ksize, window, match, mismatch, divergence. minsim, mincov, minbs, minsnp, parents, search, iters, increment, numwanted, blastlocation and realign.\n";
+		helpString += "The chimera.slayer command parameters are fasta, name, group, template, processors, dereplicate, removechimeras, trim, ksize, window, match, mismatch, divergence, minsim, mincov, minbs, minsnp, parents, iters, increment, numwanted and realign.\n";
 		helpString += "The fasta parameter allows you to enter the fasta file containing your potentially chimeric sequences, and is required, unless you have a valid current fasta file. \n";
 		helpString += "The name parameter allows you to provide a name file, if you are using reference=self. \n";
 		helpString += "The group parameter allows you to provide a group file. The group file can be used with a namesfile and reference=self. When checking sequences, only sequences from the same group as the query sequence will be used as the reference. \n";
@@ -79,21 +79,20 @@ string ChimeraSlayerCommand::getHelpString(){
 		helpString += "The increment parameter allows you to specify how far you move each window while finding chimeric sequences, default=5.\n";
 		helpString += "The numwanted parameter allows you to specify how many sequences you would each query sequence compared with, default=15.\n";
 		helpString += "The ksize parameter allows you to input kmersize, default is 7, used if search is kmer. \n";
-		helpString += "The match parameter allows you to reward matched bases in blast search, default is 5. \n";
+		helpString += "The match parameter allows you to reward matched bases, default is 5. \n";
 		helpString += "The parents parameter allows you to select the number of potential parents to investigate from the numwanted best matches after rating them, default is 3. \n";
-		helpString += "The mismatch parameter allows you to penalize mismatched bases in blast search, default is -4. \n";
+		helpString += "The mismatch parameter allows you to penalize mismatched bases, default is -4. \n";
 		helpString += "The divergence parameter allows you to set a cutoff for chimera determination, default is 1.007. \n";
 		helpString += "The iters parameter allows you to specify the number of bootstrap iters to do with the chimeraslayer method, default=1000.\n";
 		helpString += "The minsim parameter allows you to specify a minimum similarity with the parent fragments, default=90. \n";
 		helpString += "The mincov parameter allows you to specify minimum coverage by closest matches found in template. Default is 70, meaning 70%. \n";
 		helpString += "The minbs parameter allows you to specify minimum bootstrap support for calling a sequence chimeric. Default is 90, meaning 90%. \n";
 		helpString += "The minsnp parameter allows you to specify percent of SNPs to sample on each side of breakpoint for computing bootstrap support (default: 10) \n";
-		helpString += "The search parameter allows you to specify search method for finding the closest parent. Choices are blast and kmer. Default=blast. \n";
 		helpString += "The realign parameter allows you to realign the query to the potential parents. Choices are true or false, default true.  \n";
-		helpString += "The blastlocation parameter allows you to specify the location of your blast executable. By default mothur will look in ./blast/bin relative to mothur's executable.  \n";
+        helpString += "The removechimeras parameter allows you to indicate you would like to automatically remove the sequences that are flagged as chimeric. Default=t.\n";
 		helpString += "The chimera.slayer command should be in the following format: \n";
-		helpString += "chimera.slayer(fasta=yourFastaFile, reference=yourTemplate, search=yourSearch) \n";
-		helpString += "Example: chimera.slayer(fasta=AD.align, reference=core_set_aligned.imputed.fasta, search=kmer) \n";
+		helpString += "chimera.slayer(fasta=yourFastaFile, reference=yourTemplate) \n";
+		helpString += "Example: chimera.slayer(fasta=AD.align, reference=core_set_aligned.imputed.fasta) \n";
 			
 		return helpString;
 	}
@@ -110,7 +109,7 @@ string ChimeraSlayerCommand::getOutputPattern(string type) {
         if (type == "chimera") {  pattern = "[filename],slayer.chimeras"; } 
         else if (type == "accnos") {  pattern = "[filename],slayer.accnos"; } 
         else if (type == "fasta") {  pattern = "[filename],slayer.fasta"; }
-        else if (type == "count") {  pattern = "[filename],slayer.pick.count_table"; } 
+        else if (type == "count") {  pattern = "[filename],slayer.count_table"; }
         else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
@@ -121,7 +120,7 @@ string ChimeraSlayerCommand::getOutputPattern(string type) {
     }
 }
 //***************************************************************************************************************
-ChimeraSlayerCommand::ChimeraSlayerCommand(string option)  {
+ChimeraSlayerCommand::ChimeraSlayerCommand(string option) : Command()  {
 	try {
         hasCount = false;
 		
@@ -169,9 +168,6 @@ ChimeraSlayerCommand::ChimeraSlayerCommand(string option)  {
 			
             if (hasGroup && hasCount) { m->mothurOut("[ERROR]: You must enter ONLY ONE of the following: count or group.\n");  abort = true; }
 			
-            
-			
-			
 			string path;
 			map<string, string>::iterator it = parameters.find("reference");
 			//user has given a template file
@@ -226,8 +222,6 @@ ChimeraSlayerCommand::ChimeraSlayerCommand(string option)  {
 			temp = validParameter.valid(parameters, "split");			if (temp == "not found") { temp = "f"; }
 			trimera = util.isTrue(temp); 
 			
-			search = validParameter.valid(parameters, "search");			if (search == "not found") { search = "blast"; }
-			
 			temp = validParameter.valid(parameters, "iters");			if (temp == "not found") { temp = "1000"; }
 			util.mothurConvert(temp, iters); 
 			 
@@ -237,47 +231,12 @@ ChimeraSlayerCommand::ChimeraSlayerCommand(string option)  {
 			temp = validParameter.valid(parameters, "numwanted");		if (temp == "not found") { temp = "15"; }
 			util.mothurConvert(temp, numwanted);
             
-			temp = validParameter.valid(parameters, "dereplicate");
-			if (temp == "not found") { temp = "false";			}
+			temp = validParameter.valid(parameters, "dereplicate"); if (temp == "not found") { temp = "false";			}
 			dups = util.isTrue(temp);
 			
-            bool foundTool = false;
-            path = current->getProgramPath();
-            
-			blastlocation = validParameter.valid(parameters, "blastlocation");	
-			if (blastlocation == "not found") {
-                if (search == "blast") {
-                    blastlocation = "";
-                    vector<string> locations = current->getLocations();
-                    foundTool = util.findBlastLocation(blastlocation, path, locations);
-
-                    if (!foundTool){
-                        m->mothurOut("[WARNING]: Unable to locate blast executables, cannot use blast as search method. Using kmer instead.\n"); search = "kmer";
-                    }
-                }
-            }else {
-				//add / to name if needed
-				string lastChar = blastlocation.substr(blastlocation.length()-1);
-                if (lastChar != PATH_SEPARATOR) { blastlocation += PATH_SEPARATOR; }
-				blastlocation = util.getFullPathName(blastlocation);
-				
-				//test to make sure formatdb exists
-				ifstream in;
-                string formatdbCommand = blastlocation + "formatdb" + EXECUTABLE_EXT;
-				formatdbCommand = util.getFullPathName(formatdbCommand);
-				bool ableToOpen = util.openInputFile(formatdbCommand, in, "no error"); in.close();
-				if(!ableToOpen) {	m->mothurOut("[ERROR]: " + formatdbCommand + " file does not exist. mothur requires formatdb.exe to run chimera.slayer.\n");  abort = true; }
-
-				//test to make sure formatdb exists
-				ifstream in2;
-                string blastCommand = blastlocation + "megablast" + EXECUTABLE_EXT;
-				blastCommand = util.getFullPathName(blastCommand);
-				ableToOpen = util.openInputFile(blastCommand, in2, "no error"); in2.close();
-				if(!ableToOpen) {	m->mothurOut("[ERROR]: " + blastCommand + " file does not exist. mothur requires blastall.exe to run chimera.slayer.\n");  abort = true; }
-			}
-            
-			if ((search != "blast") && (search != "kmer")) { m->mothurOut(search + " is not a valid search.\n");  abort = true;  }
-			
+            temp = validParameter.valid(parameters, "removechimeras");            if (temp == "not found") { temp = "t"; }
+            removeChimeras = util.isTrue(temp);
+            			
 			if ((hasName || hasCount) && (templatefile != "self")) { m->mothurOut("You have provided a namefile or countfile and the reference parameter is not set to self. I am not sure what reference you are trying to use, aborting.\n");  abort=true; }
 			if (hasGroup && (templatefile != "self")) { m->mothurOut("You have provided a group file and the reference parameter is not set to self. I am not sure what reference you are trying to use, aborting.\n");  abort=true; }
 
@@ -310,7 +269,7 @@ int ChimeraSlayerCommand::execute(){
 
         m->mothurOut("Checking sequences from " + fastafile + " ...\n" );
         
-        long start = time(NULL);
+        long start = time(nullptr);
         if (outputdir == "") { outputdir = util.hasPath(fastafile);  }
         map<string, string> variables;
         variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
@@ -367,7 +326,7 @@ int ChimeraSlayerCommand::execute(){
                     
                     string name, group;
                     while (!in2.eof()) {
-                        in2 >> name >> group; util.gobble(in2);
+                        in2 >> name >> group; gobble(in2);
                         c.setAbund(name, group, 0);
                     }
                     in2.close();
@@ -381,7 +340,7 @@ int ChimeraSlayerCommand::execute(){
                 m->mothurOut("\n" + toString(totalChimeras) + " chimera found.\n");
             }else {
                 if (hasCount) {
-                    set<string> doNotRemove;
+                    unordered_set<string> doNotRemove;
                     CountTable c; c.readTable(newCountFile, true, true);
                     //returns non zeroed names
                     vector<string> namesInTable = c.printTable(newCountFile);
@@ -390,10 +349,9 @@ int ChimeraSlayerCommand::execute(){
                     for (int i = 0; i < namesInTable.size(); i++) { doNotRemove.insert(namesInTable[i]); }
                     
                     //remove names we want to keep from accnos file.
-                    set<string> accnosNames = util.readAccnos(accnosFileName);
-                    ofstream out2;
-                    util.openOutputFile(accnosFileName, out2);
-                    for (set<string>::iterator it = accnosNames.begin(); it != accnosNames.end(); it++) {
+                    unordered_set<string> accnosNames = util.readAccnos(accnosFileName);
+                    ofstream out2; util.openOutputFile(accnosFileName, out2);
+                    for (auto it = accnosNames.begin(); it != accnosNames.end(); it++) {
                         if (doNotRemove.count(*it) == 0) {  out2 << (*it) << endl; }
                     }
                     out2.close();
@@ -401,22 +359,65 @@ int ChimeraSlayerCommand::execute(){
             }
         }
         
-        m->mothurOut("It took " + toString(time(NULL) - start) + " secs to check " + toString(numSeqs) + " sequences.\n");
+        m->mothurOut("It took " + toString(time(nullptr) - start) + " secs to check " + toString(numSeqs) + " sequences.\n");
+        
+        if (removeChimeras) {
+            if (!util.isBlank(accnosFileName)) {
+                m->mothurOut("\nRemoving chimeras from your input files:\n");
+                
+                string inputString = "fasta=" + fastafile + ", accnos=" + accnosFileName;
+                if ((countfile != "") && (!dups))   {   inputString += ", count=" + countfile;  }
+                
+                m->mothurOut("/******************************************/\n");
+                m->mothurOut("Running command: remove.seqs(" + inputString + ")\n");
+                current->setMothurCalling(true);
+                
+                Command* removeCommand = new RemoveSeqsCommand(inputString);
+                removeCommand->execute();
+                
+                map<string, vector<string> > filenames = removeCommand->getOutputFiles();
+                
+                delete removeCommand;
+                current->setMothurCalling(false);
+                
+                m->mothurOut("/******************************************/\n");
+
+                if (countfile != "") {
+                    if (!dups) { //dereplicate=f, so remove sequences where any sample found the reads to be chimeric
+                        map<string, string> variables;
+                        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(countfile));
+                        string currentName = getOutputFileName("count", variables);
+
+                        util.renameFile(filenames["count"][0], currentName);
+                        util.mothurRemove(filenames["count"][0]);
+                        outputNames.push_back(currentName); outputTypes["count"].push_back(currentName);
+                    }//else, mothur created a modified count file removing chimeras by sample. No need to include count file on remove.seqs command. Deconvolute function created modified count table already
+                }
+                
+                map<string, string> variables;
+                variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
+                string currentName = getOutputFileName("fasta", variables);
+
+                util.renameFile(filenames["fasta"][0], currentName);
+                util.mothurRemove(filenames["fasta"][0]);
+                
+                outputNames.push_back(currentName); outputTypes["fasta"].push_back(currentName);
+                
+            }else { m->mothurOut("\nNo chimeras found, skipping remove.seqs.\n"); }
+        }
         
 		//set accnos file as new current accnosfile
 		string currentName = "";
 		itTypes = outputTypes.find("accnos");
 		if (itTypes != outputTypes.end()) { if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setAccnosFile(currentName); } }
 		
-		if (trim) {
-			itTypes = outputTypes.find("fasta");
-			if (itTypes != outputTypes.end()) { if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setFastaFile(currentName); } }
-		}
+        itTypes = outputTypes.find("fasta");
+        if (itTypes != outputTypes.end()) { if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setFastaFile(currentName); } }
 		
         itTypes = outputTypes.find("count");
 		if (itTypes != outputTypes.end()) { if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setCountFile(currentName); } }
         
-		m->mothurOut("\nOutput File Names: \n"); 
+		m->mothurOut("\nOutput File Names:\n");
 		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}	
 		m->mothurOutEndLine();
 
@@ -431,13 +432,13 @@ int ChimeraSlayerCommand::execute(){
 //**********************************************************************************************************************
 int ChimeraSlayerCommand::deconvoluteResults(string outputFileName, string accnosFileName, string trimFileName){
 	try {
-        set<string> chimerasInFile = util.readAccnos(accnosFileName);//this is so if a sequence is found to be chimera in several samples we dont write it to the results file more than once
-
-		set<string>::iterator itUnique;
+        unordered_set<string> chimerasInFile = util.readAccnos(accnosFileName);//this is so if a sequence is found to be chimera in several samples we dont write it to the results file more than once
+        unordered_set<string>::iterator itChimeras;
+        unordered_set<string>::iterator itUnique;
 		int total = 0;
         
         if (trimera) { //add in more potential uniqueNames
-            set<string> newUniqueNames = chimerasInFile;
+            unordered_set<string> newUniqueNames = chimerasInFile;
             for (itUnique = chimerasInFile.begin(); itUnique != chimerasInFile.end(); itUnique++) {
                 newUniqueNames.insert(*itUnique+"_LEFT");
                 newUniqueNames.insert(*itUnique+"_RIGHT");
@@ -445,40 +446,15 @@ int ChimeraSlayerCommand::deconvoluteResults(string outputFileName, string accno
             chimerasInFile = newUniqueNames;
         }
 		
-		//edit accnos file
-		ifstream in2; 
-		util.openInputFile(accnosFileName, in2, "no error");
-		
-		ofstream out2;
-		util.openOutputFile(accnosFileName+".temp", out2);
-		
-		string name; name = "";
-		set<string>::iterator itChimeras;
-		
-		while (!in2.eof()) {
-			if (m->getControl_pressed()) { in2.close(); out2.close(); util.mothurRemove(outputFileName); util.mothurRemove((accnosFileName+".temp")); return 0; }
-			
-			in2 >> name; util.gobble(in2);
-			
-            itChimeras = chimerasInFile.find(name);
-				
-            if (itChimeras == chimerasInFile.end()) {
-                out2 << name << endl;
-                total++;
-            }
-		}
-		in2.close();
-		out2.close();
-		
-		util.mothurRemove(accnosFileName);
-		rename((accnosFileName+".temp").c_str(), accnosFileName.c_str());
+        ofstream out2; util.openOutputFile(accnosFileName, out2);
+        for (itUnique = chimerasInFile.begin(); itUnique != chimerasInFile.end(); itUnique++) {
+            out2 << *itUnique << endl; total++;
+        }
+        out2.close();
 		
 		//edit chimera file
-		ifstream in; 
-		util.openInputFile(outputFileName, in);
-		
-		ofstream out;
-		util.openOutputFile(outputFileName+".temp", out); out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
+		ifstream in;  util.openInputFile(outputFileName, in);
+		ofstream out; util.openOutputFile(outputFileName+".temp", out); out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
 
 		string rest, parent1, parent2, line;
 		set<string> namesInFile; //this is so if a sequence is found to be chimera in several samples we dont write it to the results file more than once
@@ -492,7 +468,7 @@ int ChimeraSlayerCommand::deconvoluteResults(string outputFileName, string accno
 		
 		//get header line
 		if (!in.eof()) {
-			line = util.getline(in); util.gobble(in);
+			line = util.getline(in); gobble(in);
 			out << line << endl;
 		}
 		
@@ -504,11 +480,12 @@ int ChimeraSlayerCommand::deconvoluteResults(string outputFileName, string accno
 			
 			if (m->getControl_pressed()) { in.close(); out.close(); util.mothurRemove((outputFileName+".temp")); return 0; }
 			
-			in >> name;		util.gobble(in);
-			in >> parent1;	util.gobble(in);
+            string name = "";
+			in >> name;		gobble(in);
+			in >> parent1;	gobble(in);
 			
 			if (name == "Name") { //name = "Name" because we append the header line each time we add results from the groups
-				line = util.getline(in); util.gobble(in);
+				line = util.getline(in); gobble(in);
 			}else {
 				if (parent1 == "no") {
 					
@@ -526,7 +503,7 @@ int ChimeraSlayerCommand::deconvoluteResults(string outputFileName, string accno
 					double DivQLAQRB,PerIDQLAQRB,BootStrapA,DivQLBQRA,PerIDQLBQRA,BootStrapB;
 					string flag, range1, range2;
 					bool print = false;
-					in >> parent2 >> DivQLAQRB >> PerIDQLAQRB >> BootStrapA >> DivQLBQRA >> PerIDQLBQRA >> BootStrapB >> flag >> range1 >> range2;	util.gobble(in);
+					in >> parent2 >> DivQLAQRB >> PerIDQLAQRB >> BootStrapA >> DivQLBQRA >> PerIDQLBQRA >> BootStrapB >> flag >> range1 >> range2;	gobble(in);
 					
                     //is this name already in the file
                     itNames = namesInFile.find((name));
@@ -558,18 +535,15 @@ int ChimeraSlayerCommand::deconvoluteResults(string outputFileName, string accno
 		
 		//edit fasta file
 		if (trim) {
-			ifstream in3; 
-			util.openInputFile(trimFileName, in3);
-			
-			ofstream out3;
-			util.openOutputFile(trimFileName+".temp", out3);
+			ifstream in3;  util.openInputFile(trimFileName, in3);
+			ofstream out3; util.openOutputFile(trimFileName+".temp", out3);
 			
 			namesInFile.clear();
 			
 			while (!in3.eof()) {
 				if (m->getControl_pressed()) { in3.close(); out3.close(); util.mothurRemove(outputFileName); util.mothurRemove(accnosFileName); util.mothurRemove((trimFileName+".temp")); return 0; }
 				
-				Sequence seq(in3); util.gobble(in3);
+				Sequence seq(in3); gobble(in3);
 				
 				if (seq.getName() != "") {
                     itNames = namesInFile.find(seq.getName());
@@ -577,8 +551,7 @@ int ChimeraSlayerCommand::deconvoluteResults(string outputFileName, string accno
                     if (itNames == namesInFile.end()) { seq.printSequence(out3); }
 				}
 			}
-			in3.close();
-			out3.close();
+			in3.close(); out3.close();
 			
 			util.mothurRemove(trimFileName);
 			rename((trimFileName+".temp").c_str(), trimFileName.c_str());
@@ -661,7 +634,7 @@ string ChimeraSlayerCommand::getCountFile(string& inputFile){
 		m->mothurOut("Running command: unique.seqs(" + inputString + ")\n");
 		current->setMothurCalling(true);
         
-		Command* uniqueCommand = new DeconvoluteCommand(inputString);
+		Command* uniqueCommand = new UniqueSeqsCommand(inputString);
 		uniqueCommand->execute();
 		
 		map<string, vector<string> > filenames = uniqueCommand->getOutputFiles();
@@ -693,7 +666,7 @@ int ChimeraSlayerCommand::driverGroups(string outputFName, string accnos, string
 			
 			if (m->getControl_pressed()) {  return 0;  }
 			
-			long start = time(NULL);
+			long start = time(nullptr);
 			string thisFastaName = itFile->first;
 			map<string, int> thisPriority = itFile->second;
 			string thisoutputFileName = outputdir + util.getRootName(util.getSimpleName(thisFastaName)) + fileGroup[thisFastaName] + "slayer.chimera";
@@ -709,12 +682,11 @@ int ChimeraSlayerCommand::driverGroups(string outputFName, string accnos, string
             //This table will zero out group counts for seqs determined to be chimeric by that group.
             if (dups) {
                 if (!util.isBlank(thisaccnosFileName)) {
-                    ifstream in;
-                    util.openInputFile(thisaccnosFileName, in);
+                    ifstream in; util.openInputFile(thisaccnosFileName, in);
                     string name;
                     if (hasCount) {
                         while (!in.eof()) {
-                            in >> name; util.gobble(in);
+                            in >> name; gobble(in);
                             outCountList << name << '\t' << fileGroup[thisFastaName] << endl;
                         }
                         in.close();
@@ -726,7 +698,7 @@ int ChimeraSlayerCommand::driverGroups(string outputFName, string accnos, string
                             ofstream out;
                             util.openOutputFile(thisaccnosFileName+".temp", out);
                             while (!in.eof()) {
-                                in >> name; util.gobble(in);
+                                in >> name; gobble(in);
                                 itN = thisnamemap.find(name);
                                 if (itN != thisnamemap.end()) {
                                     vector<string> tempNames; util.splitAtComma(itN->second, tempNames);
@@ -751,7 +723,7 @@ int ChimeraSlayerCommand::driverGroups(string outputFName, string accnos, string
 			
 			totalSeqs += numSeqs;
 			
-			m->mothurOut("\nIt took " + toString(time(NULL) - start) + " secs to check " + toString(numSeqs) + " sequences from group " + fileGroup[thisFastaName] + ".\n");
+			m->mothurOut("\nIt took " + toString(time(nullptr) - start) + " secs to check " + toString(numSeqs) + " sequences from group " + fileGroup[thisFastaName] + ".\n");
 		}
 		
         if (hasCount && dups) { outCountList.close(); }
@@ -772,9 +744,9 @@ int ChimeraSlayerCommand::driver(string outputFName, string filename, string acc
         
 		MothurChimera* chimera;
 		if (templatefile != "self") { //you want to run slayer with a reference template
-			chimera = new ChimeraSlayer(filename, templatefile, trim, search, ksize, match, mismatch, window, divR, minSimilarity, minCoverage, minBS, minSNP, parents, iters, increment, numwanted, realign, blastlocation, util.getRandomNumber());
+			chimera = new ChimeraSlayer(filename, templatefile, trim, ksize, match, mismatch, window, divR, minSimilarity, minCoverage, minBS, minSNP, parents, iters, increment, numwanted, realign, util.getRandomNumber());
 		}else {
-			chimera = new ChimeraSlayer(filename, templatefile, trim, priority, search, ksize, match, mismatch, window, divR, minSimilarity, minCoverage, minBS, minSNP, parents, iters, increment, numwanted, realign, blastlocation, util.getRandomNumber());	
+			chimera = new ChimeraSlayer(filename, templatefile, trim, priority, ksize, match, mismatch, window, divR, minSimilarity, minCoverage, minBS, minSNP, parents, iters, increment, numwanted, realign, util.getRandomNumber());
 		}
 		
 		if (m->getControl_pressed()) { delete chimera; return 0; }
@@ -782,17 +754,10 @@ int ChimeraSlayerCommand::driver(string outputFName, string filename, string acc
 		if (chimera->getUnaligned()) { delete chimera; m->mothurOut("Your template sequences are different lengths, please correct.\n");  m->setControl_pressed(true); return 0; }
 		templateSeqsLength = chimera->getLength();
 		
-		ofstream out;
-		util.openOutputFile(outputFName, out);
-		
-		ofstream out2;
-		util.openOutputFile(accnos, out2);
-		
-		ofstream out3;
-		if (trim) {  util.openOutputFile(fasta, out3); }
-		
-		ifstream inFASTA;
-		util.openInputFile(filename, inFASTA);
+		ofstream out; util.openOutputFile(outputFName, out);
+		ofstream out2; util.openOutputFile(accnos, out2);
+		ofstream out3; if (trim) {  util.openOutputFile(fasta, out3); }
+		ifstream inFASTA; util.openInputFile(filename, inFASTA);
 
 		chimera->printHeader(out);
 
@@ -801,7 +766,7 @@ int ChimeraSlayerCommand::driver(string outputFName, string filename, string acc
 		
 			if (m->getControl_pressed()) {	delete chimera; out.close(); out2.close(); if (trim) { out3.close(); } inFASTA.close(); return 1;	}
 		
-			Sequence* candidateSeq = new Sequence(inFASTA);  util.gobble(inFASTA);
+			Sequence* candidateSeq = new Sequence(inFASTA);  gobble(inFASTA);
 			string candidateAligned = candidateSeq->getAligned();
 			
 			if (candidateSeq->getName() != "") { //incase there is a commented sequence at the end of a file
@@ -872,13 +837,7 @@ int ChimeraSlayerCommand::driver(string outputFName, string filename, string acc
 		//report progress
 		if((count) % 100 != 0){	m->mothurOutJustToScreen("Processing sequence: " + toString(count)+ "\n"); 		}
 		
-		int numNoParents = chimera->getNumNoParents();
-		if (numNoParents == count) { m->mothurOut("[WARNING]: megablast returned 0 potential parents for all your sequences. This could be due to formatdb.exe not being setup properly, please check formatdb.log for errors.\n");  }
-		
-		out.close();
-		out2.close();
-		if (trim) { out3.close(); }
-		inFASTA.close();
+		out.close(); out2.close(); if (trim) { out3.close(); } inFASTA.close();
 		delete chimera;
 				
 		return count;
@@ -934,21 +893,17 @@ map<string, int> ChimeraSlayerCommand::sortFastaFile(string thisfastafile, strin
         vector<seqPriorityNode> nameVector;
         
         if (hasCount) {
-            CountTable ct;
-            ct.readTable(thisdupsfile, false, false);
-            
+            CountTable ct; ct.readTable(thisdupsfile, false, false);
             nameAbund = ct.getNameMap();
         }
 
-		
-		ifstream in;
-		util.openInputFile(thisfastafile, in);
+		ifstream in; util.openInputFile(thisfastafile, in);
 		
 		while (!in.eof()) {
 			
 			if (m->getControl_pressed()) { in.close(); return nameAbund; }
 			
-			Sequence seq(in); util.gobble(in);
+			Sequence seq(in); gobble(in);
 			
             map<string, int>::iterator itNameMap = nameAbund.find(seq.getName());
             
