@@ -19,7 +19,7 @@ struct vsearchVariables {
     bool dups, useAbskew, chimealns, useMinH, useMindiv, useXn, useDn, useXa, hasCount, useMindiffs;
     string abskew, minh, mindiv, xn, dn, mindiffs;
     
-    vsearchVariables() {}
+    vsearchVariables() = default;
     void setBooleans(bool dps, bool Abskew, bool calns, bool MinH, bool Mindiv, bool Xn, bool Dn, bool mindif, bool hc) {
         useAbskew = Abskew;
         chimealns = calns;
@@ -44,7 +44,6 @@ struct vsearchVariables {
 };
 /**************************************************************************************************/
 struct vsearchData {
-    string fastafile;
     string dupsfile;
     string outputFName;
     string accnos, alns, formattedFastaFilename, templatefile, vsearchLocation;
@@ -52,15 +51,14 @@ struct vsearchData {
     map<string, vector<string> > parsedFiles;
     map<string, vector<string> > seqs2RemoveByGroup;
     
-    int count, numChimeras;
+    int count, numChimeras, processors;
     vector<string> groups;
     vsearchVariables* vars;
     MothurOut* m;
     Utils util;
     
     vsearchData(){}
-    vsearchData(map<string, vector<string> > g2f, string o, string uloc, string t, string file, string f, string n, string ac,  string al, string nc, vector<string> gr, vsearchVariables* vs) {
-        fastafile = f;
+    vsearchData(int proc, map<string, vector<string> > g2f, string o, string uloc, string t, string file, string n, string ac,  string al, string nc, vector<string> gr, vsearchVariables* vs) {
         dupsfile = n;
         formattedFastaFilename = file;
         outputFName = o;
@@ -77,6 +75,7 @@ struct vsearchData {
         driverAlns = al;
         driverOutputFName = o;
         parsedFiles = g2f;
+        processors = proc;
     }
     void setDriverNames(string o, string al, string ac) {
         driverAccnos = ac;
@@ -91,7 +90,7 @@ struct vsearchData {
 class ChimeraVsearchCommand : public Command {
 public:
     ChimeraVsearchCommand(string);
-    ~ChimeraVsearchCommand() {}
+    ~ChimeraVsearchCommand() = default;
     
     vector<string> setParameters();
     string getCommandName()			{ return "chimera.vsearch";		}
@@ -107,7 +106,7 @@ public:
     void help() { m->mothurOut(getHelpString()); }
     
 private:
-    bool abort, useAbskew, chimealns, useMinH, useMindiv, useXn, useDn, ucl, useMindiffs, hasCount, dups;
+    bool abort, useAbskew, chimealns, useMinH, useMindiv, useXn, useDn, ucl, useMindiffs, hasCount, dups, removeChimeras;
     string fastafile, templatefile, countfile, abskew, minh, mindiv, xn, dn, mindiffs, vsearchLocation;
     int processors;
     vsearchVariables* vars;
