@@ -20,8 +20,7 @@ class ClassifyOtuCommand : public Command {
 
 public:
 	ClassifyOtuCommand(string);
-	ClassifyOtuCommand();
-	~ClassifyOtuCommand() {}
+	~ClassifyOtuCommand() = default;
 	
 	vector<string> setParameters();
 	string getCommandName()			{ return "classify.otu";		}
@@ -40,7 +39,7 @@ private:
     CountTable* ct;
 	ListVector* list;
 	InputData* input;
-	string listfile, namefile, taxfile, label, outputDir, groupfile, basis, countfile, output;
+	string listfile, namefile, taxfile, label, groupfile, basis, countfile, output;
 	bool abort, allLines, probs, persample, relabund;
 	int cutoff, threshold, printlevel;
 	set<string> labels; //holds labels to be used
