@@ -20,11 +20,10 @@ vector<string> ClassifySeqsCommand::setParameters(){
         CommandParameter pname("name", "InputTypes", "", "", "NameCount", "none", "none","",false,false,true); parameters.push_back(pname);
         CommandParameter pcount("count", "InputTypes", "", "", "NameCount-CountGroup", "none", "none","",false,false,true); parameters.push_back(pcount);
 		CommandParameter pgroup("group", "InputTypes", "", "", "CountGroup", "none", "none","",false,false,true); parameters.push_back(pgroup);
-        CommandParameter phard("filter", "InputTypes", "", "", "none", "none", "none","",false,false); parameters.push_back(phard);
         CommandParameter poutput("output", "Multiple", "simple-detail", "detail", "", "", "","",false,false, true); parameters.push_back(poutput);
-		CommandParameter psearch("search", "Multiple", "kmer-blast-suffix-distance-align", "kmer", "", "", "","",false,false); parameters.push_back(psearch);
+		CommandParameter psearch("search", "Multiple", "kmer-suffix-distance-align", "kmer", "", "", "","",false,false); parameters.push_back(psearch);
 		CommandParameter pksize("ksize", "Number", "", "8", "", "", "","",false,false); parameters.push_back(pksize);
-		CommandParameter pmethod("method", "Multiple", "wang-knn-zap-opti", "wang", "", "", "","",false,false); parameters.push_back(pmethod);
+		CommandParameter pmethod("method", "Multiple", "wang-knn-zap", "wang", "", "", "","",false,false); parameters.push_back(pmethod);
 		CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
 		CommandParameter pmatch("match", "Number", "", "1.0", "", "", "","",false,false); parameters.push_back(pmatch);
         CommandParameter pprintlevel("printlevel", "Number", "", "-1", "", "", "","",false,false); parameters.push_back(pprintlevel);
@@ -64,11 +63,11 @@ string ClassifySeqsCommand::getHelpString(){
 		string helpString = "";
 		helpString += "The classify.seqs command reads a fasta file containing sequences and creates a .taxonomy file and a .tax.summary file.\n";
 		helpString += "The classify.seqs command parameters are " + getCommandParameters() + ". The reference, fasta and taxonomy parameters are required.\n";
-		helpString += "The search parameter allows you to specify the method to find most similar reference sequence.  Your options are: suffix, kmer, blast, align and distance. The default is kmer.\n";
+		helpString += "The search parameter allows you to specify the method to find most similar reference sequence.  Your options are: suffix, kmer, align and distance. The default is kmer.\n";
 		helpString += "The name parameter allows you add a names file with your fasta file.\n";
 		helpString += "The group parameter allows you add a group file so you can have the summary totals broken up by group.\n";
         helpString += "The count parameter allows you add a count file so you can have the summary totals broken up by group.\n";
-		helpString += "The method parameter allows you to specify classification method to use.  Your options are: wang, opti, knn and zap. The default is wang.\n";
+		helpString += "The method parameter allows you to specify classification method to use.  Your options are: wang, knn and zap. The default is wang.\n";
 		helpString += "The ksize parameter allows you to specify the kmer size for finding most similar template to candidate.  The default is 8.\n";
 		helpString += "The processors parameter allows you to specify the number of processors to use. The default is all available.\n";
 		helpString += "The match parameter allows you to specify the bonus for having the same base. The default is 1.0.\n";
@@ -77,7 +76,6 @@ string ClassifySeqsCommand::getHelpString(){
 		helpString += "The gapextend parameter allows you to specify the penalty for extending a gap in an alignment.  The default is -1.0.\n";
 		helpString += "The numwanted parameter allows you to specify the number of sequence matches you want with the knn method.  The default is 10.\n";
 		helpString += "The cutoff parameter allows you to specify a bootstrap confidence threshold for your taxonomy.  The default is 80.\n";
-        helpString += "The filter parameter allows you to enter a file containing the filter created by filter.seqs. Aligned reads are expected when using the opti method, the filter is used to map the columns in the query reads to the columns in the template. \n";
 		helpString += "The probs parameter shuts off the bootstrapping results for the wang and zap method. The default is true, meaning you want the bootstrapping to be shown.\n";
         helpString += "The relabund parameter allows you to indicate you want the summary file values to be relative abundances rather than raw abundances. Default=F. \n";
 		helpString += "The iters parameter allows you to specify how many iterations to do when calculating the bootstrap confidence score for your taxonomy with the wang method.  The default is 100.\n";
@@ -104,7 +102,7 @@ string ClassifySeqsCommand::getCommonQuestions(){
         vector<string> questions, issues, qanswers, ianswers, howtos, hanswers;
         
         string question = "Does the reference need to be aligned?"; questions.push_back(question);
-        string qanswer = "\tThat depends on the method. For the opti method, mothur uses the alignment to determine the probability a given base will be found in a given taxonomy at a given location in the alignment. For wang, knn and zap methods,  mothur does not require an aligned reference to assign a taxonomy. Wang use k-mers to find the probabilities of the taxonomic assignment. \n"; qanswers.push_back(qanswer);
+        string qanswer = "\tFor wang, knn and zap methods, mothur does not require an aligned reference to assign a taxonomy. Wang use k-mers to find the probabilities of the taxonomic assignment. \n"; qanswers.push_back(qanswer);
         
         question = "What reference should I use to classify?"; questions.push_back(question);
         qanswer = "\tWe provide mothur formatted references on the wiki. https://www.mothur.org/wiki/RDP_reference_files https://mothur.org/wiki/Silva_reference_files https://www.mothur.org/wiki/Greengenes-formatted_databases Alternatively, mothur allows you to create your own references as long as they are in fasta and taxonomy file format. You can find mothur's files formats here, https://www.mothur.org/wiki/File_Types. \n"; qanswers.push_back(qanswer);
@@ -144,7 +142,7 @@ string ClassifySeqsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
+ClassifySeqsCommand::ClassifySeqsCommand(string option) : Command()  {
 	try {
 		hasName = false; hasCount=false;
 		
@@ -209,13 +207,6 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 			taxonomyFileName = validParameter.validFile(parameters, "taxonomy");
 			if (taxonomyFileName == "not found") {  m->mothurOut("[ERROR]: The taxonomy parameter is a required for the classify.seqs command.\n"); abort = true;
 			}else if (taxonomyFileName == "not open") { abort = true; }
-            
-            temp = validParameter.validFile(parameters, "filter");     if (temp == "not found") { filter = ""; }
-            else if (temp == "not open") { filter = ""; abort = true; }
-            else {
-                ifstream in; util.openInputFile(temp, in);
-                in >> filter; in.close();
-            }
 			
 			search = validParameter.valid(parameters, "search");		if (search == "not found"){	search = "kmer";		}
 			
@@ -274,28 +265,6 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 				m->mothurOut("The zap method requires the kmer or align search. " + search + " will be disregarded, and kmer will be used.\n" );
 				search = "kmer";
 			}
-			
-            if (search == "blast") {
-                string blastlocation = "";
-                vector<string> locations = current->getLocations();
-                string path = current->getProgramPath();
-                bool foundTool = util.findBlastLocation(blastlocation, path, locations);
-
-                if (!foundTool){
-                    m->mothurOut("[WARNING]: Unable to locate blast executables, cannot use blast as search method. Using kmer instead.\n"); search = "kmer";
-                }
-            }
-            
-            if (!abort) {
-                if (!hasCount) {
-                    if (namefile == ""){
-                        if (fastafile != "") {
-                            vector<string> files; files.push_back(fastafile);
-                            if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-                        }
-                    }
-                }
-            }
         }
 	}
 	catch(exception& e) {
@@ -314,7 +283,6 @@ int ClassifySeqsCommand::execute(){
         
         string outputMethodTag = method;
 		if(method == "wang"){	classify = new Bayesian(taxonomyFileName, templateFileName, search, kmerSize, cutoff, iters, util.getRandomNumber(), flip, writeShortcuts, current->getVersion());	}
-		else if(method == "opti"){    classify = new OptiClassifier(taxonomyFileName, templateFileName, cutoff, iters, writeShortcuts, current->getVersion(), filter);    }
         else if(method == "knn"){	classify = new Knn(taxonomyFileName, templateFileName, search, kmerSize, gapOpen, gapExtend, match, misMatch, numWanted, util.getRandomNumber(), current->getVersion());				}
         else if(method == "zap"){	
             outputMethodTag = search + "_" + outputMethodTag;
@@ -359,15 +327,15 @@ int ClassifySeqsCommand::execute(){
         outputNames.push_back(newTaxonomyFile); outputTypes["taxonomy"].push_back(newTaxonomyFile);
         outputNames.push_back(taxSummary);	outputTypes["taxsummary"].push_back(taxSummary);
         
-        long start = time(NULL);
+        long start = time(nullptr);
         int numFastaSeqs = createProcesses(newTaxonomyFile, tempTaxonomyFile, newaccnosFile, fastafile);
         
         if (!util.isBlank(newaccnosFile)) { m->mothurOut("\n[WARNING]: mothur reversed some your sequences for a better classification.  If you would like to take a closer look, please check " + newaccnosFile + " for the list of the sequences.\n");
             outputNames.push_back(newaccnosFile); outputTypes["accnos"].push_back(newaccnosFile);
         }else { util.mothurRemove(newaccnosFile); }
         
-        m->mothurOut("\nIt took " + toString(time(NULL) - start) + " secs to classify " + toString(numFastaSeqs) + " sequences.\n\n");
-        start = time(NULL);
+        m->mothurOut("\nIt took " + toString(time(nullptr) - start) + " secs to classify " + toString(numFastaSeqs) + " sequences.\n\n");
+        start = time(nullptr);
         
         //read namefile
         map<string, vector<string> > nameMap;
@@ -392,8 +360,8 @@ int ClassifySeqsCommand::execute(){
         
         //read taxfile - this reading and rewriting is done to preserve the confidence scores.
         string name, taxon;
-        GroupMap* groupMap = NULL;
-        CountTable* ct = NULL;
+        GroupMap* groupMap = nullptr;
+        CountTable* ct = nullptr;
         PhyloSummary* taxaSum;
         
         if (hasCount) {
@@ -406,10 +374,10 @@ int ClassifySeqsCommand::execute(){
         }
         
         while (!inTax.eof()) {
-            if (m->getControl_pressed()) { outputTypes.clear(); if (ct != NULL) { delete ct; }  if (groupMap != NULL) { delete groupMap; } delete taxaSum; for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} delete classify; return 0; }
+            if (m->getControl_pressed()) { outputTypes.clear(); if (ct != nullptr) { delete ct; }  if (groupMap != nullptr) { delete groupMap; } delete taxaSum; for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} delete classify; return 0; }
             
-            inTax >> name; util.gobble(inTax);
-            taxon = util.getline(inTax); util.gobble(inTax);
+            inTax >> name; gobble(inTax);
+            taxon = util.getline(inTax); gobble(inTax);
             
             string newTax = util.addUnclassifieds(taxon, maxLevel, probs);
             
@@ -434,7 +402,7 @@ int ClassifySeqsCommand::execute(){
         util.mothurRemove(newTaxonomyFile);
         util.renameFile(unclass, newTaxonomyFile);
         
-        if (m->getControl_pressed()) {  outputTypes.clear(); if (ct != NULL) { delete ct; } if (groupMap != NULL) { delete groupMap; } for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} delete classify; delete taxaSum;  return 0; }
+        if (m->getControl_pressed()) {  outputTypes.clear(); if (ct != nullptr) { delete ct; } if (groupMap != nullptr) { delete groupMap; } for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} delete classify; delete taxaSum;  return 0; }
         
         //print summary file
         ofstream outTaxTree;
@@ -442,12 +410,12 @@ int ClassifySeqsCommand::execute(){
         taxaSum->print(outTaxTree, output);
         outTaxTree.close();
         
-        if (ct != NULL) { delete ct; }
-        if (groupMap != NULL) { delete groupMap; } delete taxaSum;
+        if (ct != nullptr) { delete ct; }
+        if (groupMap != nullptr) { delete groupMap; } delete taxaSum;
         util.mothurRemove(tempTaxonomyFile);
         delete classify;
         
-        m->mothurOut("\nIt took " + toString(time(NULL) - start) + " secs to create the summary file for " + toString(numFastaSeqs) + " sequences.\n\n");
+        m->mothurOut("\nIt took " + toString(time(nullptr) - start) + " secs to create the summary file for " + toString(numFastaSeqs) + " sequences.\n\n");
 
         m->mothurOut("\nOutput File Names: \n");
         for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
@@ -502,19 +470,15 @@ struct classifyData {
 //**********************************************************************************************************************
 void driverClassifier(classifyData* params){
     try {
-        ifstream inFASTA;
-        params->util.openInputFile(params->filename, inFASTA);
+        ifstream inFASTA; params->util.openInputFile(params->filename, inFASTA); inFASTA.seekg(params->start);
         
         string taxonomy;
-        
-        inFASTA.seekg(params->start);
-        
         bool done = false;
         string taxBuffer = ""; string taxTBuffer = ""; string accnosBuffer = "";
         while (!done) {
             if (params->m->getControl_pressed()) { break; }
             
-            Sequence* candidateSeq = new Sequence(inFASTA); params->util.gobble(inFASTA);
+            Sequence* candidateSeq = new Sequence(inFASTA); gobble(inFASTA);
             
             if (candidateSeq->getName() != "") {
                 
