@@ -77,7 +77,7 @@ string ClassifyTreeCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-ClassifyTreeCommand::ClassifyTreeCommand(string option)  {
+ClassifyTreeCommand::ClassifyTreeCommand(string option) : Command()  {
 	try {
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -142,12 +142,6 @@ ClassifyTreeCommand::ClassifyTreeCommand(string option)  {
             if ((output == "node") || (output == "taxon")) {
             }else { m->mothurOut("[ERROR]: " + output + "is not a valid output option.  Valid output options are node or taxon.\n");  abort = true; }
             
-            if (countfile == "") {
-                if (namefile == "") {
-                    vector<string> files; files.push_back(treefile);
-                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-                }
-			}
 		}
 	}
 	catch(exception& e) {
@@ -164,7 +158,7 @@ int ClassifyTreeCommand::execute(){
 		
 		cout.setf(ios::fixed, ios::floatfield); cout.setf(ios::showpoint);
 		
-		long start = time(NULL);
+		long start = time(nullptr);
         
 		/***************************************************/
 		//    reading tree info							   //
@@ -200,7 +194,7 @@ int ClassifyTreeCommand::execute(){
 			}
 		}
 		
-		m->mothurOutEndLine(); m->mothurOutEndLine(); m->mothurOut("It took " + toString(time(NULL) - start) + " secs to find the concensus taxonomies.\n"); 
+		m->mothurOutEndLine(); m->mothurOutEndLine(); m->mothurOut("It took " + toString(time(nullptr) - start) + " secs to find the concensus taxonomies.\n"); 
 		m->mothurOut("\nOutput File Names: \n"); 
 		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
         
