@@ -201,7 +201,7 @@ string CollectSharedCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-CollectSharedCommand::CollectSharedCommand(string option)  {
+CollectSharedCommand::CollectSharedCommand(string option) : Command()  {
 	try {
 		allLines = true;
 		
@@ -428,7 +428,7 @@ int CollectSharedCommand::execute(){
         
         SharedOrderVector* order = util.getNextSharedOrder(input, allLines, userLabels, processedLabels, lastLabel);
         
-        while (order != NULL) {
+        while (order != nullptr) {
             
             if (m->getControl_pressed()) { delete order; break; }
             
