@@ -18,7 +18,6 @@ class CountSeqsCommand : public Command {
 public:
 	
 	CountSeqsCommand(string);
-	CountSeqsCommand();	
 	~CountSeqsCommand(){}
 	
 	vector<string> setParameters();
@@ -36,7 +35,7 @@ public:
 	
 private:
     
-	string namefile, groupfile, outputDir, groups, sharedfile, countfile;
+	string namefile, groupfile,  groups, sharedfile, countfile;
 	bool abort, allLines, compress;
 	vector<string> Groups, outputNames;
     set<string> labels;
