@@ -17,8 +17,7 @@ class DeUniqueSeqsCommand : public Command {
 
 public:
 	DeUniqueSeqsCommand(string);
-	DeUniqueSeqsCommand();
-	~DeUniqueSeqsCommand() {}
+	~DeUniqueSeqsCommand() = default;
 	
 	vector<string> setParameters();
 	string getCommandName()			{ return "deunique.seqs";		}
@@ -36,7 +35,7 @@ public:
 	
 private:
 
-	string fastaFile, nameFile, outputDir, countfile;
+	string fastaFile, nameFile,  countfile;
 	vector<string> outputNames;
 	bool abort;
 
