@@ -19,8 +19,7 @@ class DeuniqueTreeCommand : public Command {
 	
 public:
 	DeuniqueTreeCommand(string);	
-	DeuniqueTreeCommand();
-	~DeuniqueTreeCommand() {}
+	~DeuniqueTreeCommand() = default;
 	
 	vector<string> setParameters();
 	string getCommandName()			{ return "deunique.tree";		}
@@ -39,7 +38,7 @@ private:
 	int numUniquesInName;
 	
 	bool abort;
-	string outputDir, treefile, namefile;
+	string  treefile, namefile;
 	vector<string> outputNames;
 	map<string, string> nameMap;
 	int readNamesFile();
