@@ -2,7 +2,7 @@
 //  GetCoreMicroBiomeCommand.cpp
 //  Mothur
 //
-//  Created by John Westcott on 5/8/12.
+//  Created by Sarah Westcott on 5/8/12.
 //  Copyright (c) 2012 Schloss Lab. All rights reserved.
 //
 
@@ -74,7 +74,7 @@ string GetCoreMicroBiomeCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-GetCoreMicroBiomeCommand::GetCoreMicroBiomeCommand(string option)  {
+GetCoreMicroBiomeCommand::GetCoreMicroBiomeCommand(string option) : Command()  {
 	try {
 		allLines = true;
 		
@@ -195,7 +195,7 @@ int GetCoreMicroBiomeCommand::execute(){
             if ((samples < 1) || (samples > lookup->size())) { m->mothurOut(toString(samples) + " is not a valid number for samples. Must be an integer between 1 and the number of samples in your file. Your file contains " + toString(lookup->size()) + " samples, so I will use that.\n"); samples = lookup->size(); }
         }
             
-        while (lookup != NULL) {
+        while (lookup != nullptr) {
                 
             if (m->getControl_pressed()) { delete lookup; break; }
                 
