@@ -65,7 +65,7 @@ string GetDistsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-GetDistsCommand::GetDistsCommand(string option)  {
+GetDistsCommand::GetDistsCommand(string option) : Command()  {
 	try {
 		
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -178,11 +178,10 @@ int GetDistsCommand::readPhylip(){
         variables["[extension]"] = util.getExtension(phylipfile);
 		string outputFileName = getOutputFileName("phylip", variables);
 		
-        ifstream in;
-        util.openInputFile(phylipfile, in);
+        ifstream in; util.openInputFile(phylipfile, in);
         
         float distance;
-        int square, nseqs; 
+        int square, nseqs; square = 0;
         string name;
         unsigned int row;
         set<unsigned int> rows; //converts names in names to a index
@@ -308,7 +307,7 @@ int GetDistsCommand::readPhylip(){
             
             ifstream in3;
             util.openInputFile(outputFileName+".temp", in3);
-            in3 >> nseqs; util.gobble(in3);
+            in3 >> nseqs; gobble(in3);
             char buffer[4096];        
             while (!in3.eof()) {
                 in3.read(buffer, 4096);
@@ -343,8 +342,7 @@ int GetDistsCommand::readColumn(){
 		ofstream out;
 		util.openOutputFile(outputFileName, out);
         
-        ifstream in;
-        util.openInputFile(columnfile, in);
+        ifstream in; util.openInputFile(columnfile, in);
         
         set<string> foundNames;
         string firstName, secondName;
@@ -353,7 +351,7 @@ int GetDistsCommand::readColumn(){
             
             if (m->getControl_pressed()) { out.close(); in.close(); return 0; }
             
-            in >> firstName >> secondName >> distance; util.gobble(in);
+            in >> firstName >> secondName >> distance; gobble(in);
             
             //are both names in the accnos file
             if ((names.count(firstName) != 0) && (names.count(secondName) != 0)) {
