@@ -24,6 +24,7 @@ vector<string> GetGroupsCommand::setParameters(){
 		CommandParameter pgroup("group", "InputTypes", "", "", "CountGroup", "sharedGroup", "FNGLT","group",false,false, true); parameters.push_back(pgroup);		
         CommandParameter pdesign("design", "InputTypes", "", "", "none", "sharedGroup", "FNGLT","design",false,false, true); parameters.push_back(pdesign);
 		CommandParameter plist("list", "InputTypes", "", "", "none", "none", "FNGLT","list",false,false, true); parameters.push_back(plist);
+        CommandParameter pflow("flow", "InputTypes", "", "", "none", "none", "FNGLT","flow",false,false, true); parameters.push_back(pflow);
 		CommandParameter ptaxonomy("taxonomy", "InputTypes", "", "", "none", "none", "FNGLT","taxonomy",false,false, true); parameters.push_back(ptaxonomy);
         CommandParameter pphylip("phylip", "InputTypes", "", "", "none", "PhylipColumn", "none","phylip",false,false,true); parameters.push_back(pphylip);
         CommandParameter pcolumn("column", "InputTypes", "", "", "none", "PhylipColumn", "none","column",false,false,true); parameters.push_back(pcolumn);
@@ -38,6 +39,7 @@ vector<string> GetGroupsCommand::setParameters(){
         
         vector<string> tempOutNames;
         outputTypes["fasta"] = tempOutNames;
+        outputTypes["flow"] = tempOutNames;
         outputTypes["taxonomy"] = tempOutNames;
         outputTypes["name"] = tempOutNames;
         outputTypes["group"] = tempOutNames;
@@ -84,6 +86,7 @@ string GetGroupsCommand::getOutputPattern(string type) {
         string pattern = "";
         
         if (type == "fasta")            {   pattern = "[filename],pick,[extension]";    }
+        else if (type == "flow")        {   pattern = "[filename],pick,[extension]";    }
         else if (type == "taxonomy")    {   pattern = "[filename],pick,[extension]";    }
         else if (type == "name")        {   pattern = "[filename],pick,[extension]";    }
         else if (type == "group")       {   pattern = "[filename],pick,[extension]";    }
@@ -103,7 +106,7 @@ string GetGroupsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-GetGroupsCommand::GetGroupsCommand(string option)  {
+GetGroupsCommand::GetGroupsCommand(string option) : Command()  {
 	try {
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -127,6 +130,11 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
 			if (fastafile == "not open") { fastafile = ""; abort = true; }
 			else if (fastafile == "not found") {  fastafile = "";  }
 			else { current->setFastaFile(fastafile); }
+            
+            flowfile = validParameter.validFile(parameters, "flow");
+            if (flowfile == "not open") { flowfile = ""; abort = true; }
+            else if (flowfile == "not found") {  flowfile = "";  }
+            else { current->setFlowFile(flowfile); }
 			
             phylipfile = validParameter.validFile(parameters, "phylip");
             if (phylipfile == "not open") { phylipfile = ""; abort = true; }
@@ -236,15 +244,8 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
             
             if ((Sets.size() != 0) && (designfile == "")) { m->mothurOut("[ERROR]: You must provide a design file when using the sets parameter.\n"); abort = true;  }
 			
-			if ((phylipfile == "") && (columnfile == "") && (fastafile == "") && (namefile == "") && (countfile == "") && (groupfile == "")  && (designfile == "") && (sharedfile == "") && (listfile == "") && (taxfile == ""))  { m->mothurOut("[ERROR]: You must provide at least one of the following: fasta, name, taxonomy, group, shared, design, count, phylip, column or list.\n");  abort = true; }
-			if (((groupfile == "") && (countfile == "")) && ((namefile != "") || (fastafile != "") || (listfile != "") || (taxfile != "")))  { m->mothurOut("[ERROR]: If using a fasta, name, taxonomy, group or list, then you must provide a group or count file.\n");  abort = true; }
-            
-            if (countfile == "") {
-                if ((namefile == "") && ((fastafile != "") || (taxfile != ""))){
-                    vector<string> files; files.push_back(fastafile); files.push_back(taxfile);
-                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-                }
-            }
+			if ((flowfile == "") && (phylipfile == "") && (columnfile == "") && (fastafile == "") && (namefile == "") && (countfile == "") && (groupfile == "")  && (designfile == "") && (sharedfile == "") && (listfile == "") && (taxfile == ""))  { m->mothurOut("[ERROR]: You must provide at least one of the following: fasta, name, taxonomy, group, shared, design, count, phylip, column or list.\n");  abort = true; }
+			if (((groupfile == "") && (countfile == "")) && ((flowfile != "") || (namefile != "") || (fastafile != "") || (listfile != "") || (taxfile != "")))  { m->mothurOut("[ERROR]: If using a fasta, flow, name, taxonomy, group or list, then you must provide a group or count file.\n");  abort = true; }
 		}
 		
 	}
@@ -306,6 +307,7 @@ int GetGroupsCommand::execute(){
 		//read through the correct file and output lines you want to keep
 		if (namefile != "")			{		readName();		}
 		if (fastafile != "")		{		readFasta();	}
+        if (flowfile != "")        {        readFlow();    }
 		if (groupfile != "")		{		readGroup();	}
 		if (listfile != "")			{		readList();		}
 		if (taxfile != "")			{		readTax();		}
@@ -394,11 +396,8 @@ void GetGroupsCommand::readFasta(){
         variables["[extension]"] = util.getExtension(fastafile);
 		string outputFileName = getOutputFileName("fasta", variables);
 		
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
-		
-		ifstream in;
-		util.openInputFile(fastafile, in);
+		ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(fastafile, in);
 		string name;
 		
 		bool wroteSomething = false;
@@ -428,7 +427,7 @@ void GetGroupsCommand::readFasta(){
 					}
 				}
 			}
-			util.gobble(in);
+			gobble(in);
 		}
 		in.close();	
 		out.close();
@@ -444,6 +443,65 @@ void GetGroupsCommand::readFasta(){
 	}
 }
 //**********************************************************************************************************************
+void GetGroupsCommand::readFlow(){
+    try {
+        string thisOutputDir = outputdir;
+        if (outputdir == "") {  thisOutputDir += util.hasPath(flowfile);  }
+        map<string, string> variables;
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(flowfile));
+        variables["[extension]"] = util.getExtension(flowfile);
+        string outputFileName = getOutputFileName("flow", variables);
+        
+        ofstream out; util.openOutputFile(outputFileName, out);
+        ifstream in; util.openInputFile(flowfile, in);
+        string name, flows;
+        
+        bool wroteSomething = false;
+        int selectedCount = 0;
+        
+        in >> flows; gobble(in); //read numflows
+        out << flows << endl;
+        
+        while(!in.eof()){
+            if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return; }
+            
+            in >> name; gobble(in);
+            flows = util.getline(in); gobble(in);
+
+            if (name != "") {
+                //if this name is in the accnos file
+                if (names.count(name) != 0) {
+                    wroteSomething = true;
+                    
+                    out << name << '\t' << flows << endl;
+                    selectedCount++;
+                }else{
+                    //if you are not in the accnos file check if you are a name that needs to be changed
+                    map<string, string>::iterator it = uniqueToRedundant.find(name);
+                    if (it != uniqueToRedundant.end()) {
+                        wroteSomething = true;
+                        name = it->second;
+                        out << name << '\t' << flows << endl;
+                        selectedCount++;
+                    }
+                }
+            }
+            gobble(in);
+        }
+        in.close();
+        out.close();
+        
+        if (wroteSomething == false) {  m->mothurOut("Your file does NOT contain sequences from the groups you wish to get.\n");   }
+        outputTypes["flow"].push_back(outputFileName);  outputNames.push_back(outputFileName);
+        
+        m->mothurOut("Selected " + toString(selectedCount) + " sequences from your flow file.\n");
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GetGroupsCommand", "readFasta");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
 void GetGroupsCommand::readShared(){
 	try {
 		string thisOutputDir = outputdir;
@@ -457,7 +515,7 @@ void GetGroupsCommand::readShared(){
 		
 		bool wroteSomething = false;
         bool printHeaders = true;
-		while(lookup != NULL) {
+		while(lookup != nullptr) {
 			
             variables["[tag]"] = lookup->getLabel();
             string outputFileName = getOutputFileName("shared", variables);
@@ -506,7 +564,7 @@ void GetGroupsCommand::readList(){
 		bool wroteSomething = false;
 		int selectedCount = 0;
 		
-        while(list != NULL) {
+        while(list != nullptr) {
 			
             selectedCount = 0;
             
@@ -590,11 +648,8 @@ void GetGroupsCommand::readName(){
         variables["[extension]"] = util.getExtension(namefile);
 		string outputFileName = getOutputFileName("name", variables);
 		
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
-		
-		ifstream in;
-		util.openInputFile(namefile, in);
+		ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(namefile, in);
 		string name, firstCol, secondCol;
 		
 		bool wroteSomething = false;
@@ -603,7 +658,7 @@ void GetGroupsCommand::readName(){
 		while(!in.eof()){
 			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return; }
 			
-			in >> firstCol;		util.gobble(in);		
+			in >> firstCol;		gobble(in);		
 			in >> secondCol;			
 			
 			vector<string> parsedNames;
@@ -646,7 +701,7 @@ void GetGroupsCommand::readName(){
 				}
 			}
 			
-			util.gobble(in);
+			gobble(in);
 		}
 		in.close();
 		out.close();
@@ -672,11 +727,8 @@ void GetGroupsCommand::readGroup(){
         variables["[extension]"] = util.getExtension(groupfile);
 		string outputFileName = getOutputFileName("group", variables);
 		
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
-		
-		ifstream in;
-		util.openInputFile(groupfile, in);
+		ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(groupfile, in);
 		string name, group;
 		
 		bool wroteSomething = false;
@@ -685,7 +737,7 @@ void GetGroupsCommand::readGroup(){
 		while(!in.eof()){
 			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return; }
 			
-			in >> name;		util.gobble(in);		//read from first column
+			in >> name;		gobble(in);		//read from first column
 			in >> group;			//read from second column
 			
 			//if this name is in the accnos file
@@ -695,7 +747,7 @@ void GetGroupsCommand::readGroup(){
 				selectedCount++;
 			}
 			
-			util.gobble(in);
+			gobble(in);
 		}
 		in.close();
 		out.close();
@@ -720,7 +772,7 @@ void GetGroupsCommand::readDesign(){
         variables["[extension]"] = util.getExtension(designfile);
 		string outputFileName = getOutputFileName("design", variables);
 		
-        DesignMap designMap(designfile);
+        DesignMap designMap(designfile); if (m->getControl_pressed()) { return ; }
         
         bool wroteSomething = false;
         
@@ -755,11 +807,8 @@ void GetGroupsCommand::readTax(){
         variables["[extension]"] = util.getExtension(taxfile);
 		string outputFileName = getOutputFileName("taxonomy", variables);
 		
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
-		
-		ifstream in;
-		util.openInputFile(taxfile, in);
+		ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(taxfile, in);
 		string name, tax;
 		
 		bool wroteSomething = false;
@@ -768,8 +817,8 @@ void GetGroupsCommand::readTax(){
 		while(!in.eof()){
 			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return; }
 			
-            in >> name; util.gobble(in);
-            tax = util.getline(in); util.gobble(in);
+            in >> name; gobble(in);
+            tax = util.getline(in); gobble(in);
 			
 			//if this name is in the accnos file
 			if (names.count(name) != 0) {
@@ -807,11 +856,10 @@ void GetGroupsCommand::readPhylip(){
         variables["[extension]"] = util.getExtension(phylipfile);
         string outputFileName = getOutputFileName("phylip", variables);
         
-        ifstream in;
-        util.openInputFile(phylipfile, in);
+        ifstream in; util.openInputFile(phylipfile, in);
         
         float distance;
-        int square, nseqs;
+        int square, nseqs; square = 0;
         string name;
         unsigned int row;
         set<unsigned int> rows; //converts names in names to a index
@@ -873,8 +921,7 @@ void GetGroupsCommand::readPhylip(){
         if (m->getControl_pressed()) {  return; }
         
         //read through file only printing rows and columns of seqs in names
-        ifstream inPhylip;
-        util.openInputFile(phylipfile, inPhylip);
+        ifstream inPhylip; util.openInputFile(phylipfile, inPhylip);
         
         inPhylip >> numTest;
         
@@ -937,7 +984,7 @@ void GetGroupsCommand::readPhylip(){
             
             ifstream in3;
             util.openInputFile(outputFileName+".temp", in3);
-            in3 >> nseqs; util.gobble(in3);
+            in3 >> nseqs; gobble(in3);
             char buffer[4096];
             while (!in3.eof()) {
                 in3.read(buffer, 4096);
@@ -966,11 +1013,8 @@ void GetGroupsCommand::readColumn(){
         string outputFileName = getOutputFileName("column", variables);
         outputTypes["column"].push_back(outputFileName);  outputNames.push_back(outputFileName);
         
-        ofstream out;
-        util.openOutputFile(outputFileName, out);
-        
-        ifstream in;
-        util.openInputFile(columnfile, in);
+        ofstream out; util.openOutputFile(outputFileName, out);
+        ifstream in; util.openInputFile(columnfile, in);
         
         set<string> foundNames;
         string firstName, secondName;
@@ -979,7 +1023,7 @@ void GetGroupsCommand::readColumn(){
             
             if (m->getControl_pressed()) { out.close(); in.close(); return; }
             
-            in >> firstName >> secondName >> distance; util.gobble(in);
+            in >> firstName >> secondName >> distance; gobble(in);
             
             //are both names in the accnos file
             if ((names.count(firstName) != 0) && (names.count(secondName) != 0)) {
@@ -1025,7 +1069,7 @@ void GetGroupsCommand::fillNames(){
 //**********************************************************************************************************************
 void GetGroupsCommand::fillGroupsFromDesign(){
     try {
-        DesignMap designMap(designfile);
+        DesignMap designMap(designfile); if (m->getControl_pressed()) { return ; }
         Groups = designMap.getNamesGroups(Sets);
     }
     catch(exception& e) {
