@@ -20,7 +20,6 @@ class HeatMapSimCommand : public Command {
 
 public:
 	HeatMapSimCommand(string);
-	HeatMapSimCommand();
 	~HeatMapSimCommand(){}
 	
 	vector<string> setParameters();
@@ -37,13 +36,13 @@ public:
 	
 	
 private:
-	InputData* input;
+	
 	vector<Calculator*> heatCalculators;
 	HeatMapSim* heatmap;
-	OptionParser* parser;
+	
 	bool abort, allLines;
 	set<string> labels; //holds labels to be used
-	string format, groups, label, calc, sharedfile, phylipfile, columnfile, countfile, namefile, outputDir, inputfile;
+	string format, groups, label, calc, sharedfile, phylipfile, columnfile, countfile, namefile,  inputfile;
 	vector<string> Estimators, Groups, outputNames;
 	int fontsize;
 	
