@@ -19,7 +19,6 @@ class HomovaCommand : public Command {
 	
 public:
 	HomovaCommand(string);
-	HomovaCommand();
 	~HomovaCommand(){}
 	
 	vector<string> setParameters();
@@ -42,7 +41,7 @@ private:
 
 	bool abort;
 	vector<string> outputNames, Sets;
-	string outputDir, inputDir, designFileName, phylipFileName;
+	string  inputDir, designFileName, phylipFileName;
 	vector< vector<double> > distanceMatrix;
 	int iters;
 	double experimentwiseAlpha;
