@@ -66,7 +66,7 @@ string KruskalWallisCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-KruskalWallisCommand::KruskalWallisCommand(string option)  {
+KruskalWallisCommand::KruskalWallisCommand(string option) : Command()  {
 	try {
 
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -127,7 +127,7 @@ int KruskalWallisCommand::execute(){
 		
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
         
-        DesignMap designMap(designfile);
+        DesignMap designMap(designfile); if (m->getControl_pressed()) { return 0; }
         
         //if user did not select class use first column
         if (mclass == "") {  mclass = designMap.getDefaultClass(); m->mothurOut("\nYou did not provide a class, using " + mclass +".\n\n"); }
@@ -140,7 +140,7 @@ int KruskalWallisCommand::execute(){
         SharedRAbundVectors* lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
         vector<string> currentLabels = lookup->getOTUNames();
         
-        while (lookup != NULL) {
+        while (lookup != nullptr) {
             
             if (m->getControl_pressed()) { delete lookup; break; }
             
@@ -185,7 +185,7 @@ int KruskalWallisCommand::process(vector<SharedRAbundVector*>& lookup, DesignMap
             string treatment = designMap.get(group, mclass); //get value for this group in this category
             treatments.insert(treatment);
         }
-        if (treatments.size() < 2) { m->mothurOut("[ERROR]: need at least 2 things to classes to compare, quitting.\n"); m->setControl_pressed(true); }
+        if (treatments.size() < 2) { m->mothurOut("[ERROR]: need at least 2 things for classes to compare, quitting.\n"); m->setControl_pressed(true); }
         
         LinearAlgebra linear;
         for (int i = 0; i < numBins; i++) {
