@@ -48,28 +48,30 @@ public:
     void help() { m->mothurOut(getHelpString()); }
     
 private:
-    bool abort, allLines, wilc, wilcsamename, curv, subject, normMillion;
+    bool abort, allLines, wilc, wilcsamename, curv, subject, normMillion, pairwise, runAll;
     string  sharedfile, designfile, mclass, subclass, rankTec, multiClassStrat, sets, inputfile, clrfile, format;
     vector<string> outputNames, Sets;
     set<string> labels;
     double anovaAlpha, wilcoxonAlpha, fBoots, ldaThreshold;
     int nlogs, iters, strict, minC;
     
-    int process(SharedRAbundFloatVectors*&, SharedCLRVectors*&, DesignMap&);
+    int process(SharedRAbundFloatVectors*&, SharedCLRVectors*&, DesignMap&, string combo);
     int normalize(SharedRAbundFloatVectors*&, SharedCLRVectors*&);
     map<int, double> runKruskalWallis(SharedRAbundFloatVectors*&, SharedCLRVectors*&, DesignMap&);
-    map<int, double> runWilcoxon(SharedRAbundFloatVectors*&, SharedCLRVectors*&, DesignMap&, map<int, double>, map<string, set<string> >& class2SubClasses, map<string, vector<int> >& subClass2GroupIndex, map<string, string>);
+    map<int, double> runWilcoxon(SharedRAbundFloatVectors*&, SharedCLRVectors*&, map<int, double>, map<string, set<string> >& class2SubClasses, map<string, vector<int> >& subClass2GroupIndex, map<string, string>);
     map<int, double> testLDA(SharedRAbundFloatVectors*&, SharedCLRVectors*&, map<int, double>, map<string, vector<int> >& class2GroupIndex, map<string, vector<int> >&);
     vector< vector<double> > getMeans(SharedRAbundFloatVectors*& lookup, SharedCLRVectors*& clr, map<string, vector<int> >& class2GroupIndex);
     
     bool contastWithinClassesOrFewPerClass(vector< vector<double> >&, vector<int> rands, int minCl, map<string, vector<int> > class2GroupIndex,  map<int, string> indexToClass);
     vector< vector<double> > lda(vector< vector<double> >& adjustedLookup, vector<int> rand_s, map<int, string>& indexToClass, vector<string>);
     bool testOTUWilcoxon(map<string, set<string> >& class2SubClasses, vector<float> abunds, map<string, vector<int> >& subClass2GroupIndex, map<string, string>);
-    int printResults(vector< vector<double> >, map<int, double>, map<int, double>, string, vector<string>, vector<string>);
+    void printResults(vector< vector<double> >, map<int, double>, map<int, double>, string, vector<string>, vector<string>, string);
+    void printResultsAll(vector< vector<double> >, map<int, double>, map<int, double>, string, vector<string>, vector<string>, string);
     
     //for testing
     bool printToCoutForRTesting(vector< vector<double> >& adjustedLookup, vector<int> rand_s, map<string, vector<int> >& class2GroupIndex, map<int, double> bins, map<string, vector<int> >&, vector<string>, vector<string>);
     int makeShared(int);
+    void runPairwiseAnalysis(DesignMap&);
 };
 
 /**************************************************************************************************/
