@@ -69,7 +69,7 @@ string MergeFileCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-MergeFileCommand::MergeFileCommand(string option)  {
+MergeFileCommand::MergeFileCommand(string option) : Command()  {
 	try {
  		if(option == "help") { help(); abort = true; calledHelp = true; }
         else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -80,14 +80,14 @@ MergeFileCommand::MergeFileCommand(string option)  {
 			
 			ValidParameters validParameter;
 
-            string inputDir = validParameter.valid(parameters, "inputdir");
+            string inputDir = validParameter.validPath(parameters, "inputdir");
             if (inputDir == "not found"){    inputDir = "";        }
             
-			string fileList = validParameter.valid(parameters, "input");
+			string fileList = validParameter.validPath(parameters, "input");
             if(fileList == "not found") { appendMode = false; fileList = "";  }
 			else{ 	util.splitAtDash(fileList, fileNames);	}
             
-            outputFileName = validParameter.valid(parameters, "output");
+            outputFileName = validParameter.validPath(parameters, "output");
             if (outputFileName == "not found") { appendMode = false; outputFileName = "";   }
 
             fastafile = validParameter.validFile(parameters, "fasta");
@@ -222,14 +222,13 @@ string MergeFileCommand::mergeFileData(){
         bool useTax = false;
         if (taxfile != "") {  util.readTax(taxfile, taxMap, false);  useTax = true;  }
         
-        ifstream in;
-        util.openInputFile(fastafile, in);
+        ifstream in; util.openInputFile(fastafile, in);
 
         while(!in.eof()){
             
             if (m->getControl_pressed()) { break; }
             
-            Sequence currSeq(in); util.gobble(in);
+            Sequence currSeq(in); gobble(in);
             
             string comment = " ";
             
