@@ -47,7 +47,7 @@ string MergeTaxSummaryCommand::getHelpString(){
 	}
 }
 //**********************************************************************************************************************
-MergeTaxSummaryCommand::MergeTaxSummaryCommand(string option)  {
+MergeTaxSummaryCommand::MergeTaxSummaryCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help();  abort = true; calledHelp = true;    }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;   }
@@ -57,10 +57,10 @@ MergeTaxSummaryCommand::MergeTaxSummaryCommand(string option)  {
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			string inputDir = validParameter.valid(parameters, "inputdir");		
+			string inputDir = validParameter.validPath(parameters, "inputdir");
 			if (inputDir == "not found"){	inputDir = "";		}
 			
-			string fileList = validParameter.valid(parameters, "input");
+			string fileList = validParameter.validPath(parameters, "input");
 			if(fileList == "not found") { m->mothurOut("you must enter two or more file names\n");   abort=true;  }
 			else{ 	util.splitAtDash(fileList, fileNames);	}
 			
@@ -72,43 +72,8 @@ MergeTaxSummaryCommand::MergeTaxSummaryCommand(string option)  {
 			}
 			else{
 				for(int i=0;i<numInputFiles;i++){
-					if (inputDir != "") {
-                        string path = util.hasPath(fileNames[i]);
-                        //if the user has not given a path then, add inputdir. else leave path alone.
-                        if (path == "") {	fileNames[i] = inputDir + fileNames[i];		}
-                    }
-                    
-                    bool ableToOpen;
-                    ifstream in;
-                    ableToOpen = util.openInputFile(fileNames[i], in, "noerror");
-                    in.close();	
-                    
-                    //if you can't open it, try default location
-                    if (!ableToOpen) {
-                        if (current->getDefaultPath() != "") { //default path is set
-                            string tryPath = current->getDefaultPath() + util.getSimpleName(fileNames[i]);
-                            m->mothurOut("Unable to open " + fileNames[i] + ". Trying default " + tryPath); m->mothurOutEndLine();
-                            ifstream in2;
-                            ableToOpen = util.openInputFile(tryPath, in2, "noerror");
-                            in2.close();
-                            fileNames[i] = tryPath;
-                        }
-                    }
-                    
-                    //if you can't open it, try output location
-                    if (!ableToOpen) {
-                        if (current->getOutputDir() != "") { //default path is set
-                            string tryPath = current->getOutputDir() + util.getSimpleName(fileNames[i]);
-                            m->mothurOut("Unable to open " + fileNames[i] + ". Trying output directory " + tryPath); m->mothurOutEndLine();
-                            ifstream in2;
-                            ableToOpen = util.openInputFile(tryPath, in2, "noerror");
-                            in2.close();
-                            fileNames[i] = tryPath;
-                        }
-                    }
-                    
-                    
-                    
+                    bool ableToOpen = util.checkLocations(fileNames[i], current->getLocations());
+            
                     if (!ableToOpen) { 
                         m->mothurOut("Unable to open " + fileNames[i] + ". It will be disregarded.\n");  
                         //erase from file list
@@ -118,7 +83,7 @@ MergeTaxSummaryCommand::MergeTaxSummaryCommand(string option)  {
 				}
 			}   
 			
-			outputFileName = validParameter.valid(parameters, "output");
+			outputFileName = validParameter.validPath(parameters, "output");
 			if (outputFileName == "not found") { m->mothurOut("you must enter an output file name\n");   abort=true;  }
 			else if (outputdir != "") { outputFileName = outputdir + util.getSimpleName(outputFileName);   }
             
@@ -147,9 +112,8 @@ int MergeTaxSummaryCommand::execute(){
        
         for (int i = 0; i < fileNames.size(); i++) {
             
-            ifstream in;
-            util.openInputFile(fileNames[i], in);
-            string temp = util.getline(in); util.gobble(in);
+            ifstream in; util.openInputFile(fileNames[i], in);
+            string temp = util.getline(in); gobble(in);
             vector<string> headers = util.splitWhiteSpace(temp);
             
             vector<string> thisFilesGroups;
@@ -165,9 +129,9 @@ int MergeTaxSummaryCommand::execute(){
                 
                 if (m->getControl_pressed()) {   return 0;  }
                 
-                in >> level >> rankId; util.gobble(in);
+                in >> level >> rankId; gobble(in);
                
-                string rest = util.getline(in); util.gobble(in);
+                string rest = util.getline(in); gobble(in);
                 vector<string> pieces = util.splitWhiteSpaceWithQuotes(rest);
                 
                 map<string, int> groupCounts;
