@@ -75,7 +75,7 @@ string NormalizeSharedCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-NormalizeSharedCommand::NormalizeSharedCommand(string option) {
+NormalizeSharedCommand::NormalizeSharedCommand(string option) : Command() {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -185,7 +185,7 @@ int NormalizeSharedCommand::execute(){
 			}
 			
 			bool printHeaders = true;
-            while (lookup != NULL) {
+            while (lookup != nullptr) {
                 
                 if (m->getControl_pressed()) { delete lookup; break; }
                 
@@ -212,7 +212,7 @@ int NormalizeSharedCommand::execute(){
 			}
 			
             bool printHeaders = true;
-            while (lookupFloat != NULL) {
+            while (lookupFloat != nullptr) {
                     
                 if (m->getControl_pressed()) { delete lookupFloat; break; }
 
