@@ -18,7 +18,6 @@
 class OTUAssociationCommand : public Command {
 public:
 	OTUAssociationCommand(string);
-	OTUAssociationCommand();
 	~OTUAssociationCommand(){}
 	
 	vector<string> setParameters();
@@ -34,18 +33,18 @@ public:
 	void help() { m->mothurOut(getHelpString()); }	
 private:
 	
-	string sharedfile, relabundfile, metadatafile, groups, label, inputFileName, outputDir, method;
+	string sharedfile, relabundfile, metadatafile, groups, label, inputFileName,  method;
 	bool abort, pickedGroups, allLines;
     double cutoff;
 	set<string> labels;
     vector< vector< double> > metadata;
 	
 	vector<string> outputNames, Groups, metadataLabels;
-	int processShared();
-	int process(SharedRAbundVectors*&);
-	int processRelabund();
-	int process(SharedRAbundFloatVectors*&);
-    int readMetadata();
+	void processShared();
+	void process(SharedRAbundVectors*&);
+	void processRelabund();
+	void process(SharedRAbundFloatVectors*&);
+    void readMetadata();
 	
 };
 
