@@ -12,7 +12,7 @@
 
 #include "mothur.h"
 #include "command.hpp"
-#include "database.hpp"
+#include "searchdatabase.hpp"
 #include "alignment.hpp"
 #include "validcalculator.h"
 #include "calculator.h"
@@ -21,7 +21,6 @@
 
 #include "gotohoverlap.hpp"
 #include "needlemanoverlap.hpp"
-#include "blastalign.hpp"
 #include "noalign.hpp"
 
 #include "ignoregaps.h"
@@ -34,8 +33,9 @@
 class PairwiseSeqsCommand : public Command {
 	
 public:
-	PairwiseSeqsCommand(string);	
-	~PairwiseSeqsCommand() {}
+	PairwiseSeqsCommand(string);
+    PairwiseSeqsCommand(StorageDatabase*&, vector< vector< int > > kmerDB, vector< int > lengths, string, double, string, int); //used by mothur's splitMatrix class to avoid rereading files
+	~PairwiseSeqsCommand() = default;
 	
 	vector<string> setParameters();
 	string getCommandName()			{ return "pairwise.seqs";		}
@@ -50,17 +50,21 @@ public:
 	void help() { m->mothurOut(getHelpString()); }	
 	
 private:
-	SequenceDB alignDB;
+    StorageDatabase* alignDB;
 	
 	void createProcesses(string);
     bool sanityCheck();
     
+    bool abort, countends, compress, fitCalc;
 	string fastaFileName, align, calc,  output, oldfastafile, column;
-	float match, misMatch, gapOpen, gapExtend, cutoff;
-	int processors, longestBase, numDistsBelowCutoff;
-	vector<string> Estimators, outputNames;
+	float match, misMatch, gapOpen, gapExtend, cutoff, kmerCutoff;
+	int processors, longestBase, numDistsBelowCutoff, kmerSize;
+	vector<string> outputNames;
+    
+    vector< vector< int > > kmerDB; //kmerDB[0] = vector<int> maxKmers long, contains kmer counts
+    vector< int > lengths;
+	
 	
-	bool abort, countends, compress, fitCalc;
 };
 
 #endif
