@@ -91,7 +91,7 @@ string PhyloDiversityCommand::getOutputPattern(string type) {
 }
 
 //**********************************************************************************************************************
-PhyloDiversityCommand::PhyloDiversityCommand(string option)  {
+PhyloDiversityCommand::PhyloDiversityCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -179,13 +179,6 @@ PhyloDiversityCommand::PhyloDiversityCommand(string option)  {
 			}
 			
 			if ((!collect) && (!rarefy) && (!summary)) { m->mothurOut("No outputs selected. You must set either collect, rarefy or summary to true, summary=T by default.\n");  abort=true; }
-			
-			if (countfile=="") {
-                if (namefile == "") {
-                    vector<string> files; files.push_back(treefile);
-                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-                } 
-            }
 		}
 		
 	}
@@ -252,7 +245,7 @@ int PhyloDiversityCommand::execute(){
 		
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
-        long start = time(NULL);
+        long start = time(nullptr);
         
 		current->setTreeFile(treefile);
         TreeReader* reader;
@@ -353,7 +346,7 @@ int PhyloDiversityCommand::execute(){
 		
 		if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	} return 0; }
 
-        m->mothurOut("It took " + toString(time(NULL) - start) + " secs to run phylo.diversity.\n");
+        m->mothurOut("It took " + toString(time(nullptr) - start) + " secs to run phylo.diversity.\n");
         
 		m->mothurOut("\nOutput File Names: \n"); 
 		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
