@@ -14,14 +14,13 @@
 #include "sharedrabundvectors.hpp"
 #include "listvector.hpp"
 #include "removeseqscommand.h"
-#include "removeotulabelscommand.h"
+#include "removeotuscommand.h"
 
 class RemoveLineageCommand : public Command {
 	
 	public:
 	
 		RemoveLineageCommand(string);
-		RemoveLineageCommand();
 		~RemoveLineageCommand(){};
 	
 		vector<string> setParameters();
@@ -38,7 +37,7 @@ class RemoveLineageCommand : public Command {
 	
 	private:
 		vector<string> outputNames, listOfTaxons;
-		string fastafile, namefile, groupfile, alignfile, listfile, countfile, taxfile, outputDir, taxons, sharedfile, constaxonomy, label;
+		string fastafile, namefile, groupfile, alignfile, listfile, countfile, taxfile,  taxons, sharedfile, constaxonomy, label;
 		bool abort, dups;
 		
         string readTax();
