@@ -21,7 +21,6 @@ class RemoveRareCommand : public Command {
 public:
 	
 	RemoveRareCommand(string);	
-	RemoveRareCommand();
 	~RemoveRareCommand(){}
 	
 	vector<string> setParameters();
@@ -38,17 +37,17 @@ public:
 	void help() { m->mothurOut(getHelpString()); }	
 	
 private:
-	string sabundfile, rabundfile, sharedfile, groupfile, countfile, listfile, outputDir, groups, label;
+	string sabundfile, rabundfile, sharedfile, groupfile, countfile, listfile,  groups, label;
 	int nseqs, allLines;
 	bool abort, byGroup;
 	vector<string> outputNames, Groups;
 	set<string> labels;
 	
-	int processSabund();
-	int processRabund();
+	void processSabund();
+	void processRabund();
 	int processList();
-	int processShared();
-	int processLookup(SharedRAbundVectors*&);
+	void processShared();
+	void processLookup(SharedRAbundVectors*&);
 	
 };
 
