@@ -8,7 +8,7 @@
  */
 
 #include "seqerrorcommand.h"
-#include "reportfile.h"
+#include "alignreport.hpp"
 #include "qualityscores.h"
 #include "refchimeratest.h"
 
@@ -107,7 +107,7 @@ string SeqErrorCommand::getOutputPattern(string type) {
 }
 //***************************************************************************************************************
 
-SeqErrorCommand::SeqErrorCommand(string option)  {
+SeqErrorCommand::SeqErrorCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -169,11 +169,6 @@ SeqErrorCommand::SeqErrorCommand(string option)  {
             temp = validParameter.valid(parameters, "aligned");			if (temp == "not found"){	temp = "t";				}
 			aligned = util.isTrue(temp); 
 
-			if ((namesFileName == "") && (queryFileName != "")){
-				vector<string> files; files.push_back(queryFileName); 
-				if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-			}
-
             if(aligned ){
                 if((reportFileName != "" && qualFileName == "") || (reportFileName == "" && qualFileName != "")){
                     m->mothurOut("if you use either a qual file or a report file, you have to have both.");
@@ -201,7 +196,7 @@ int SeqErrorCommand::execute(){
 	try{
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
-		long start = time(NULL);
+		long start = time(nullptr);
 		maxLength = 5000;
 		totalBases = 0;
 		totalMatches = 0;
@@ -266,8 +261,49 @@ int SeqErrorCommand::execute(){
 			megAlignmentFile << megaAlignVector[i] << endl;
 		}
         megAlignmentFile.close();
+        
+        m->mothurOut("It took " + toString(time(nullptr) - start) + " secs to check " + toString(numSeqs) + " sequences.\n");
+        
+        
+        bool extraOutput = false;
+        if (extraOutput) {
+            //read error.chimera
+            ifstream in; util.openInputFile(errorChimeraFileName, in);
+            int chimeraCount = 0;
+            while (!in.eof()) {
+                if (m->getControl_pressed()) { break; }
+                
+                string line = util.getline(in); gobble(in);
+                vector<string> pieces = util.splitWhiteSpace(line);
+                
+                if (pieces.size() != 0) {
+                    if (pieces[pieces.size()-1] == "2") {
+                        chimeraCount++;
+                    }
+                }
+            }
+            in.close();
+            m->mothurOut("\nTrue chimeras found: " + toString(chimeraCount) + "\n");
+            m->mothurOut("\nReference names for chimeras:\n\n");
+            
+            //read error.summary to extract names of parents
+            ifstream in2; util.openInputFile(errorSummaryFileName, in2);
+            while (!in2.eof()) {
+                if (m->getControl_pressed()) { break; }
+                
+                string line = util.getline(in2); gobble(in2);
+                vector<string> pieces = util.splitWhiteSpace(line);
+                
+                if (pieces.size() != 0) {
+                    if (pieces[pieces.size()-1] == "2") {
+                        cout << pieces[1] << endl;
+                    }
+                }
+            }
+            in2.close();
+            
+        }
       
-		m->mothurOut("It took " + toString(time(NULL) - start) + " secs to check " + toString(numSeqs) + " sequences.\n");
 		 
 		m->mothurOut("\nOutput File Names: \n");
 		for (int i = 0; i < outputNames.size(); i++) { m->mothurOut(outputNames[i]+"\n");  }
@@ -452,7 +488,7 @@ long long SeqErrorCommand::process(string filename, string qFileName, string rFi
         
         int maxMismatch = 0;
         
-        ReportFile report;
+        AlignReport report;
         QualityScores quality;
         
         misMatchCounts.resize(11, 0);
@@ -484,7 +520,8 @@ long long SeqErrorCommand::process(string filename, string qFileName, string rFi
             util.openInputFile(qFileName, qualFile);
             
             //gobble headers
-            report.readHeaders(reportFile, rFileName);
+            util.openInputFile(reportFileName, reportFile);
+            report.readHeaders(reportFile);
             
             qualForwardMap.resize(maxLength);
             qualReverseMap.resize(maxLength);
@@ -650,7 +687,7 @@ vector<Sequence> SeqErrorCommand::getReferences(string refFileName){
         while(!referenceFile.eof()){
             if (m->getControl_pressed()) { break; }
             
-            Sequence currentSeq(referenceFile); util.gobble(referenceFile);
+            Sequence currentSeq(referenceFile); gobble(referenceFile);
             
             int numAmbigs = currentSeq.getAmbigBases();
             if(numAmbigs > 0){	numAmbigSeqs++;	}
