@@ -74,7 +74,7 @@ string SeqSummaryCommand::getOutputPattern(string type) {
 }
 //***************************************************************************************************************
 
-SeqSummaryCommand::SeqSummaryCommand(string option)  {
+SeqSummaryCommand::SeqSummaryCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -142,12 +142,6 @@ SeqSummaryCommand::SeqSummaryCommand(string option)  {
 			string temp = validParameter.valid(parameters, "processors");	if (temp == "not found"){	temp = current->getProcessors();	}
 			processors = current->setProcessors(temp);
 			
-            if (countfile == "") {
-                if (namefile == "") {
-                    vector<string> files; files.push_back(fastafile);
-                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-                }
-            }
 		}
 	}
 	catch(exception& e) {
@@ -162,7 +156,7 @@ int SeqSummaryCommand::execute(){
 		
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
-        long start = time(NULL);
+        long start = time(nullptr);
         
         map<string, string> variables; 
 		variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
@@ -243,8 +237,8 @@ int SeqSummaryCommand::execute(){
         if ((namefile == "") && (countfile == "") && (summaryfile == "")) {  m->mothurOut("# of Seqs:\t" + toString(numUniques)); m->mothurOutEndLine(); }
         else { m->mothurOut("# of unique seqs:\t" + toString(numUniques)); m->mothurOutEndLine(); m->mothurOut("total # of seqs:\t" + toString(size)); m->mothurOutEndLine(); }
         
-        if (((namefile == "") && (countfile == "")) && (summaryfile == "")) {  m->mothurOut("\nIt took " + toString(time(NULL) - start) + " secs to summarize " + toString(numUniques) + " sequences.\n");  }
-        else{  m->mothurOut("\nIt took " + toString(time(NULL) - start) + " secs to summarize " + toString(size) + " sequences.\n");   }
+        if (((namefile == "") && (countfile == "")) && (summaryfile == "")) {  m->mothurOut("\nIt took " + toString(time(nullptr) - start) + " secs to summarize " + toString(numUniques) + " sequences.\n");  }
+        else{  m->mothurOut("\nIt took " + toString(time(nullptr) - start) + " secs to summarize " + toString(size) + " sequences.\n");   }
         
         m->mothurOut("\nOutput File Names:\n");
         if ((summaryfile == "") && (contigsfile == "") && (alignfile == "")) {
