@@ -19,7 +19,6 @@ class SetLogFileCommand : public Command {
 	
 public:
 	SetLogFileCommand(string);
-	SetLogFileCommand() { setParameters(); abort = true; calledHelp = true; }
 	~SetLogFileCommand(){}
 	
 	vector<string> setParameters();
@@ -35,7 +34,7 @@ public:
 	void help() { m->mothurOut(getHelpString()); }	
 	
 private:
-	string name, outputDir;
+	string name;
 	bool abort, append;
 	vector<string> outputNames;
 		
