@@ -14,7 +14,7 @@
 #include "myseqdist.h"
 #include "seqnoise.h"
 #include "sequenceparser.h"
-#include "deconvolutecommand.h"
+#include "uniqueseqscommand.h"
 #include "clustercommand.h"
 
 //**********************************************************************************************************************
@@ -23,7 +23,7 @@ class ShhhSeqsCommand : public Command {
 	
 public:
 	ShhhSeqsCommand(string);
-	~ShhhSeqsCommand() {}
+	~ShhhSeqsCommand() = default;
 	
 	vector<string> setParameters();
 	string getCommandName()			{ return "shhh.seqs";	}
