@@ -80,7 +80,7 @@ string SortSeqsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-SortSeqsCommand::SortSeqsCommand(string option)  {
+SortSeqsCommand::SortSeqsCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -129,11 +129,6 @@ SortSeqsCommand::SortSeqsCommand(string option)  {
             
 			if ((fastafile == "") && (namefile == "") && (taxfile == "") && (flowfile == "") && (qualfile == ""))  { m->mothurOut("You must provide at least one of the following: fasta, name, taxonomy, flow or quality.\n"); abort = true; }
 			
-            
-            if ((fastafile != "") && (namefile == "")) {
-                vector<string> files; files.push_back(fastafile);
-                if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-            }
 		}
         
 	}
@@ -154,7 +149,7 @@ int SortSeqsCommand::execute(){
             vector<string> temp;
             util.readAccnos(accnosfile, temp);
             for (int i = 0; i < temp.size(); i++) {  names[temp[i]] = i;  }
-            m->mothurOut("\nUsing " + accnosfile + " to determine the order. It contains " + toString(temp.size()) + " representative sequences.\n");	
+            m->mothurOut("\nUsing " + accnosfile + " to determine the order. It contains " + toString(temp.size()) + " sequences.\n");	
         }
         
 		if (fastafile != "")		{		readFasta();	}
@@ -219,11 +214,8 @@ int SortSeqsCommand::readFasta(){
 		string outputFileName = getOutputFileName("fasta", variables);
 		outputTypes["fasta"].push_back(outputFileName);  outputNames.push_back(outputFileName);
         
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
-		
-		ifstream in;
-		util.openInputFile(fastafile, in);
+		ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(fastafile, in);
 		string name;
 		
         if (names.size() != 0) {//this is not the first file we are reading so we need to use the order we already have
@@ -250,7 +242,7 @@ int SortSeqsCommand::readFasta(){
                             m->mothurOut(name + " was not in the contained the file which determined the order, adding it to the end.\n");
                         }
                     }
-                    util.gobble(in);
+                    gobble(in);
                 }
                 in.close();
                 out.close();
@@ -297,7 +289,7 @@ int SortSeqsCommand::readFasta(){
                                 }
                             }else { m->mothurOut("[ERROR]: in logic of readFasta function.\n"); m->setControl_pressed(true); }
                         }
-                        util.gobble(in2);
+                        gobble(in2);
                     }
                     in2.close();	
 
@@ -331,14 +323,16 @@ int SortSeqsCommand::readFasta(){
                     if (name != "") {
                         map<string, int>::iterator it = names.find(name);
                         if (it != names.end()) { //we found it, so put it in the vector in the right place.
-                            seqs[it->second] = currSeq;  
+                            if (it->second > (seqs.size()-1)) {
+                                m->mothurOut("[WARNING]: Ignoring " + name + ". Could you have duplicate names in your fasta file?\n");
+                            }else { seqs[it->second] = currSeq;  }
                         }else { //if we cant find it then add it to the end
                             names[name] = seqs.size();
                             seqs.push_back(currSeq);
                             m->mothurOut(name + " was not in the contained the file which determined the order, adding it to the end.\n");
                         }
                     }
-                    util.gobble(in);
+                    gobble(in);
                 }
                 in.close();	
                 
@@ -368,7 +362,7 @@ int SortSeqsCommand::readFasta(){
                     count++;
                     currSeq.printSequence(out);
                 }
-                util.gobble(in);
+                gobble(in);
             }
             in.close();	
             out.close();
@@ -395,15 +389,12 @@ int SortSeqsCommand::readFlow(){
 		string outputFileName = getOutputFileName("flow", variables);
 		outputTypes["flow"].push_back(outputFileName);  outputNames.push_back(outputFileName);
         
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
-		
-		ifstream in;
-		util.openInputFile(flowfile, in);
+		ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(flowfile, in);
         int numFlows;
 		string name;
         
-        in >> numFlows; util.gobble(in);
+        in >> numFlows; gobble(in);
 		
         if (names.size() != 0) {//this is not the first file we are reading so we need to use the order we already have
             
@@ -429,10 +420,9 @@ int SortSeqsCommand::readFlow(){
                             m->mothurOut(name + " was not in the contained the file which determined the order, adding it to the end.\n");
                         }
                     }
-                    util.gobble(in);
+                    gobble(in);
                 }
-                in.close();
-                out.close();
+                in.close(); out.close();
                 
                 int numLeft = names.size();
                 if (numNamesInFile < numLeft) { numLeft = numNamesInFile; }
@@ -446,7 +436,7 @@ int SortSeqsCommand::readFlow(){
                 while (numLeft > 0) {
                     
                     ifstream in2;
-                    util.openInputFile(flowfile, in2); in2 >> numFlows; util.gobble(in2);
+                    util.openInputFile(flowfile, in2); in2 >> numFlows; gobble(in2);
                     
                     if (m->getControl_pressed()) { in2.close();  util.mothurRemove(outputFileName);  return 0; }
                     
@@ -475,7 +465,7 @@ int SortSeqsCommand::readFlow(){
                                 }
                             }else { m->mothurOut("[ERROR]: in logic of readFlow function.\n"); m->setControl_pressed(true); }
                         }
-                        util.gobble(in2);
+                        gobble(in2);
                     }
                     in2.close();	
                     
@@ -517,7 +507,7 @@ int SortSeqsCommand::readFlow(){
                             m->mothurOut(name + " was not in the contained the file which determined the order, adding it to the end.\n");
                         }
                     }
-                    util.gobble(in);
+                    gobble(in);
                 }
                 in.close();	
                 
@@ -548,7 +538,7 @@ int SortSeqsCommand::readFlow(){
                     count++;
                     out << name << '\t' << rest << endl;
                 }
-                util.gobble(in);
+                gobble(in);
             }
             in.close();	
             out.close();
@@ -576,11 +566,8 @@ int SortSeqsCommand::readQual(){
 		string outputFileName = getOutputFileName("qfile", variables);
         outputTypes["qfile"].push_back(outputFileName);  outputNames.push_back(outputFileName);
         
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
-		
-		ifstream in;
-		util.openInputFile(qualfile, in);
+		ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(qualfile, in);
 		string name;
 		
         if (names.size() != 0) {//this is not the first file we are reading so we need to use the order we already have
@@ -608,7 +595,7 @@ int SortSeqsCommand::readQual(){
                             m->mothurOut(name + " was not in the contained the file which determined the order, adding it to the end.\n");
                         }
                     }
-                    util.gobble(in);
+                    gobble(in);
                 }
                 in.close();
                 out.close();
@@ -657,7 +644,7 @@ int SortSeqsCommand::readQual(){
                                 }
                             }else { m->mothurOut("[ERROR]: in logic of readQual function.\n"); m->setControl_pressed(true); }
                         }
-                        util.gobble(in2);
+                        gobble(in2);
                     }
                     in2.close();	
                     
@@ -702,7 +689,7 @@ int SortSeqsCommand::readQual(){
                             m->mothurOut(name + " was not in the contained the file which determined the order, adding it to the end.\n");
                         }
                     }
-                    util.gobble(in);
+                    gobble(in);
                 }
                 in.close();	
                 
@@ -724,7 +711,7 @@ int SortSeqsCommand::readQual(){
                 QualityScores currQual;
                 currQual = QualityScores(in);  
                                
-                util.gobble(in);
+                gobble(in);
                 
                 if (currQual.getName() != "") {
                     //if this name is in the accnos file
@@ -732,7 +719,7 @@ int SortSeqsCommand::readQual(){
                     count++;
                     currQual.printQScores(out);
                 }
-                util.gobble(in);
+                gobble(in);
             }
             in.close();	
             out.close();
@@ -759,11 +746,8 @@ int SortSeqsCommand::readName(){
 		string outputFileName = getOutputFileName("name", variables);
         outputTypes["name"].push_back(outputFileName);  outputNames.push_back(outputFileName);
         
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
-        
-		ifstream in;
-		util.openInputFile(namefile, in);
+		ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(namefile, in);
 		string name, firstCol, secondCol;
 		
         if (names.size() != 0) {//this is not the first file we are reading so we need to use the order we already have
@@ -773,8 +757,8 @@ int SortSeqsCommand::readName(){
                 while(!in.eof()){
                     if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
                     
-                    in >> firstCol;		util.gobble(in);		
-                    in >> secondCol;    util.gobble(in);
+                    in >> firstCol;		gobble(in);		
+                    in >> secondCol;    gobble(in);
                     
                     if (firstCol != "") {
                         map<string, int>::iterator it = names.find(firstCol);
@@ -803,8 +787,8 @@ int SortSeqsCommand::readName(){
             while(!in.eof()){
                 if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
                 
-                in >> firstCol;		util.gobble(in);		
-                in >> secondCol;    util.gobble(in);
+                in >> firstCol;		gobble(in);		
+                in >> secondCol;    gobble(in);
                 
                 if (firstCol != "") {
                     //if this name is in the accnos file
@@ -812,7 +796,7 @@ int SortSeqsCommand::readName(){
                     count++;
                     out << firstCol << '\t' << secondCol << endl;
                 }
-                util.gobble(in);
+                gobble(in);
             }
             in.close();	
             out.close();
@@ -839,11 +823,8 @@ int SortSeqsCommand::readTax(){
 
         outputTypes["taxonomy"].push_back(outputFileName);  outputNames.push_back(outputFileName);
         
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
-        
-		ifstream in;
-		util.openInputFile(taxfile, in);
+		ofstream out; util.openOutputFile(outputFileName, out);
+		ifstream in; util.openInputFile(taxfile, in);
 		string name, tax;
 		
 		if (names.size() != 0) {//this is not the first file we are reading so we need to use the order we already have
@@ -853,8 +834,8 @@ int SortSeqsCommand::readTax(){
             while(!in.eof()){
                 if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
                 
-                in >> name; util.gobble(in);
-                tax = util.getline(in); util.gobble(in);
+                in >> name; gobble(in);
+                tax = util.getline(in); gobble(in);
                 
                 if (name != "") {
                     map<string, int>::iterator it = names.find(name);
@@ -883,8 +864,8 @@ int SortSeqsCommand::readTax(){
             while(!in.eof()){
                 if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
                 
-                in >> name; util.gobble(in);
-                tax = util.getline(in); util.gobble(in);
+                in >> name; gobble(in);
+                tax = util.getline(in); gobble(in);
                 
                 if (name != "") {
                     //if this name is in the accnos file
@@ -892,7 +873,7 @@ int SortSeqsCommand::readTax(){
                     count++;
                     out << name << '\t' << tax << endl;
                 }
-                util.gobble(in);
+                gobble(in);
             }
             in.close();	
             out.close();
