@@ -56,73 +56,72 @@ void CurrentFile::printCurrentFiles(string filename)  {
         lock_guard<std::mutex> guard(currentProtector);
         
         if (filename != "") {
-            ofstream out;
-            util.openOutputFile(filename, out);
+            ofstream out; util.openOutputFile(filename, out);
             
-            if (accnosfile != "")		{  m->mothurOut("accnos=" + accnosfile, out); m->mothurOutEndLine(out);           }
-            if (columnfile != "")		{  m->mothurOut("column=" + columnfile, out); m->mothurOutEndLine(out);			}
-            if (designfile != "")		{  m->mothurOut("design=" + designfile, out); m->mothurOutEndLine(out);			}
-            if (fastafile != "")		{  m->mothurOut("fasta=" + fastafile, out); m->mothurOutEndLine(out);				}
-            if (groupfile != "")		{  m->mothurOut("group=" + groupfile, out); m->mothurOutEndLine(out);				}
-            if (listfile != "")			{  m->mothurOut("list=" + listfile, out); m->mothurOutEndLine(out);				}
-            if (namefile != "")			{  m->mothurOut("name=" + namefile, out); m->mothurOutEndLine(out);				}
-            if (oligosfile != "")		{  m->mothurOut("oligos=" + oligosfile, out); m->mothurOutEndLine(out);			}
-            if (orderfile != "")		{  m->mothurOut("order=" + orderfile, out); m->mothurOutEndLine(out);				}
-            if (ordergroupfile != "")	{  m->mothurOut("ordergroup=" + ordergroupfile, out); m->mothurOutEndLine(out);	}
-            if (phylipfile != "")		{  m->mothurOut("phylip=" + phylipfile, out); m->mothurOutEndLine(out);			}
-            if (qualfile != "")			{  m->mothurOut("qfile=" + qualfile, out); m->mothurOutEndLine(out);				}
-            if (rabundfile != "")		{  m->mothurOut("rabund=" + rabundfile, out); m->mothurOutEndLine(out);			}
-            if (relabundfile != "")		{  m->mothurOut("relabund=" + relabundfile, out); m->mothurOutEndLine(out);		}
-            if (clrfile != "")          {  m->mothurOut("clr=" + clrfile, out); m->mothurOutEndLine(out);               }
-            if (sabundfile != "")		{  m->mothurOut("sabund=" + sabundfile, out); m->mothurOutEndLine(out);			}
-            if (sfffile != "")			{  m->mothurOut("sff=" + sfffile, out); m->mothurOutEndLine(out);					}
-            if (sharedfile != "")		{  m->mothurOut("shared=" + sharedfile, out); m->mothurOutEndLine(out);			}
-            if (taxonomyfile != "")		{  m->mothurOut("taxonomy=" + taxonomyfile, out); m->mothurOutEndLine(out);		}
-            if (constaxonomyfile != "")	{  m->mothurOut("constaxonomy=" + constaxonomyfile, out); m->mothurOutEndLine(out);}
-            if (contigsreportfile != ""){  m->mothurOut("contigsreport=" + contigsreportfile, out); m->mothurOutEndLine(out);}
-            if (treefile != "")			{  m->mothurOut("tree=" + treefile, out); m->mothurOutEndLine(out);				}
-            if (flowfile != "")			{  m->mothurOut("flow=" + flowfile, out); m->mothurOutEndLine(out);				}
-            if (biomfile != "")			{  m->mothurOut("biom=" + biomfile, out); m->mothurOutEndLine(out);				}
-            if (countfile != "")        {  m->mothurOut("count=" + countfile, out); m->mothurOutEndLine(out);        }
-            if (processors != "1")		{  m->mothurOut("processors=" + processors, out); m->mothurOutEndLine(out);		}
-            if (summaryfile != "")		{  m->mothurOut("summary=" + summaryfile, out); m->mothurOutEndLine(out);         }
-            if (filefile != "")         {  m->mothurOut("file=" + filefile, out); m->mothurOutEndLine(out);               }
-            if (samplefile != "")       {  m->mothurOut("sample=" + samplefile, out); m->mothurOutEndLine(out);               }
+            if (accnosfile != "")		{  out << "accnos=" + accnosfile + "\n";           }
+            if (columnfile != "")		{  out << "column=" + columnfile + "\n";			}
+            if (designfile != "")		{  out << "design=" + designfile + "\n";		}
+            if (fastafile != "")		{  out << "fasta=" + fastafile + "\n";			}
+            if (groupfile != "")		{  out << "group=" + groupfile + "\n";			}
+            if (listfile != "")			{  out << "list=" + listfile + "\n";				}
+            if (namefile != "")			{  out << "name=" + namefile + "\n";			}
+            if (oligosfile != "")		{  out << "oligos=" + oligosfile + "\n";			}
+            if (orderfile != "")		{  out << "order=" + orderfile + "\n";			}
+            if (ordergroupfile != "")	{  out << "ordergroup=" + ordergroupfile + "\n";	}
+            if (phylipfile != "")		{  out << "phylip=" + phylipfile + "\n";		}
+            if (qualfile != "")			{  out << "qfile=" + qualfile + "\n";				}
+            if (rabundfile != "")		{  out << "rabund=" + rabundfile + "\n";			}
+            if (relabundfile != "")		{  out << "relabund=" + relabundfile + "\n";		}
+            if (clrfile != "")          {  out << "clr=" + clrfile + "\n";               }
+            if (sabundfile != "")		{  out << "sabund=" + sabundfile + "\n";			}
+            if (sfffile != "")			{  out << "sff=" + sfffile + "\n";			}
+            if (sharedfile != "")		{  out << "shared=" + sharedfile + "\n";			}
+            if (taxonomyfile != "")		{  out << "taxonomy=" + taxonomyfile + "\n";		}
+            if (constaxonomyfile != "")	{  out << "constaxonomy=" + constaxonomyfile + "\n"; }
+            if (contigsreportfile != ""){  out << "contigsreport=" + contigsreportfile + "\n";}
+            if (treefile != "")			{  out << "tree=" + treefile + "\n";			}
+            if (flowfile != "")			{  out << "flow=" + flowfile + "\n";			}
+            if (biomfile != "")			{  out << "biom=" + biomfile + "\n";			}
+            if (countfile != "")        {  out << "count=" + countfile + "\n";      }
+            if (processors != "1")		{  out << "processors=" + processors + "\n";		}
+            if (summaryfile != "")		{  out << "summary=" + summaryfile + "\n";       }
+            if (filefile != "")         {  out << "file=" + filefile + "\n";           }
+            if (samplefile != "")       {  out << "sample=" + samplefile + "\n";              }
             
             out.close();
-            
-        }else {
-            if (accnosfile != "")		{  m->mothurOut("accnos=" + accnosfile); m->mothurOutEndLine();			}
-            if (columnfile != "")		{  m->mothurOut("column=" + columnfile); m->mothurOutEndLine();			}
-            if (designfile != "")		{  m->mothurOut("design=" + designfile); m->mothurOutEndLine();			}
-            if (fastafile != "")		{  m->mothurOut("fasta=" + fastafile); m->mothurOutEndLine();				}
-            if (groupfile != "")		{  m->mothurOut("group=" + groupfile); m->mothurOutEndLine();				}
-            if (listfile != "")			{  m->mothurOut("list=" + listfile); m->mothurOutEndLine();				}
-            if (namefile != "")			{  m->mothurOut("name=" + namefile); m->mothurOutEndLine();				}
-            if (oligosfile != "")		{  m->mothurOut("oligos=" + oligosfile); m->mothurOutEndLine();			}
-            if (orderfile != "")		{  m->mothurOut("order=" + orderfile); m->mothurOutEndLine();				}
-            if (ordergroupfile != "")	{  m->mothurOut("ordergroup=" + ordergroupfile); m->mothurOutEndLine();	}
-            if (phylipfile != "")		{  m->mothurOut("phylip=" + phylipfile); m->mothurOutEndLine();			}
-            if (qualfile != "")			{  m->mothurOut("qfile=" + qualfile); m->mothurOutEndLine();				}
-            if (rabundfile != "")		{  m->mothurOut("rabund=" + rabundfile); m->mothurOutEndLine();			}
-            if (relabundfile != "")		{  m->mothurOut("relabund=" + relabundfile); m->mothurOutEndLine();		}
-            if (clrfile != "")          {  m->mothurOut("clr=" + clrfile); m->mothurOutEndLine();               }
-            if (sabundfile != "")		{  m->mothurOut("sabund=" + sabundfile); m->mothurOutEndLine();			}
-            if (sfffile != "")			{  m->mothurOut("sff=" + sfffile); m->mothurOutEndLine();					}
-            if (sharedfile != "")		{  m->mothurOut("shared=" + sharedfile); m->mothurOutEndLine();			}
-            if (taxonomyfile != "")		{  m->mothurOut("taxonomy=" + taxonomyfile); m->mothurOutEndLine();		}
-            if (constaxonomyfile != "")	{  m->mothurOut("constaxonomy=" + constaxonomyfile); m->mothurOutEndLine();}
-            if (contigsreportfile != ""){  m->mothurOut("contigsreport=" + contigsreportfile); m->mothurOutEndLine();}
-            if (treefile != "")			{  m->mothurOut("tree=" + treefile); m->mothurOutEndLine();				}
-            if (flowfile != "")			{  m->mothurOut("flow=" + flowfile); m->mothurOutEndLine();				}
-            if (biomfile != "")			{  m->mothurOut("biom=" + biomfile); m->mothurOutEndLine();				}
-            if (countfile != "")        {  m->mothurOut("count=" + countfile); m->mothurOutEndLine();        }
-            if (processors != "1")		{  m->mothurOut("processors=" + processors); m->mothurOutEndLine();		}
-            if (summaryfile != "")		{  m->mothurOut("summary=" + summaryfile); m->mothurOutEndLine();         }
-            if (filefile != "")         {  m->mothurOut("file=" + filefile); m->mothurOutEndLine();               }
-            if (samplefile != "")       {  m->mothurOut("sample=" + samplefile); m->mothurOutEndLine();               }
         }
         
+        if (accnosfile != "")		{  m->mothurOut("accnos=" + accnosfile); m->mothurOutEndLine();			}
+        if (columnfile != "")		{  m->mothurOut("column=" + columnfile); m->mothurOutEndLine();			}
+        if (designfile != "")		{  m->mothurOut("design=" + designfile); m->mothurOutEndLine();			}
+        if (fastafile != "")		{  m->mothurOut("fasta=" + fastafile); m->mothurOutEndLine();				}
+        if (groupfile != "")		{  m->mothurOut("group=" + groupfile); m->mothurOutEndLine();				}
+        if (listfile != "")			{  m->mothurOut("list=" + listfile); m->mothurOutEndLine();				}
+        if (namefile != "")			{  m->mothurOut("name=" + namefile); m->mothurOutEndLine();				}
+        if (oligosfile != "")		{  m->mothurOut("oligos=" + oligosfile); m->mothurOutEndLine();			}
+        if (orderfile != "")		{  m->mothurOut("order=" + orderfile); m->mothurOutEndLine();				}
+        if (ordergroupfile != "")	{  m->mothurOut("ordergroup=" + ordergroupfile); m->mothurOutEndLine();	}
+        if (phylipfile != "")		{  m->mothurOut("phylip=" + phylipfile); m->mothurOutEndLine();			}
+        if (qualfile != "")			{  m->mothurOut("qfile=" + qualfile); m->mothurOutEndLine();				}
+        if (rabundfile != "")		{  m->mothurOut("rabund=" + rabundfile); m->mothurOutEndLine();			}
+        if (relabundfile != "")		{  m->mothurOut("relabund=" + relabundfile); m->mothurOutEndLine();		}
+        if (clrfile != "")          {  m->mothurOut("clr=" + clrfile); m->mothurOutEndLine();               }
+        if (sabundfile != "")		{  m->mothurOut("sabund=" + sabundfile); m->mothurOutEndLine();			}
+        if (sfffile != "")			{  m->mothurOut("sff=" + sfffile); m->mothurOutEndLine();					}
+        if (sharedfile != "")		{  m->mothurOut("shared=" + sharedfile); m->mothurOutEndLine();			}
+        if (taxonomyfile != "")		{  m->mothurOut("taxonomy=" + taxonomyfile); m->mothurOutEndLine();		}
+        if (constaxonomyfile != "")	{  m->mothurOut("constaxonomy=" + constaxonomyfile); m->mothurOutEndLine();}
+        if (contigsreportfile != ""){  m->mothurOut("contigsreport=" + contigsreportfile); m->mothurOutEndLine();}
+        if (treefile != "")			{  m->mothurOut("tree=" + treefile); m->mothurOutEndLine();				}
+        if (flowfile != "")			{  m->mothurOut("flow=" + flowfile); m->mothurOutEndLine();				}
+        if (biomfile != "")			{  m->mothurOut("biom=" + biomfile); m->mothurOutEndLine();				}
+        if (countfile != "")        {  m->mothurOut("count=" + countfile); m->mothurOutEndLine();        }
+        if (processors != "1")		{  m->mothurOut("processors=" + processors); m->mothurOutEndLine();		}
+        if (summaryfile != "")		{  m->mothurOut("summary=" + summaryfile); m->mothurOutEndLine();         }
+        if (filefile != "")         {  m->mothurOut("file=" + filefile); m->mothurOutEndLine();               }
+        if (samplefile != "")       {  m->mothurOut("sample=" + samplefile); m->mothurOutEndLine();               }
+        
+        
     }
     catch(exception& e) {
         m->errorOut(e, "CurrentFile", "printCurrentFiles");
@@ -238,15 +237,19 @@ int CurrentFile::setProcessors(string p)  {
     }
 }
 /*********************************************************************************************/
-void CurrentFile::setDefaultPath(string pathname)  {
+void CurrentFile::setDefaultPath(vector<string> pathnames)  {
     try {
         lock_guard<std::mutex> guard(currentProtector);
         
-        if (pathname != "") { //add / to name if needed
-            string lastChar = pathname.substr(pathname.length()-1);
-            if (lastChar != PATH_SEPARATOR) { pathname += PATH_SEPARATOR; }
+        defaultPath.clear();
+        for (int i = 0; i < pathnames.size(); i++) {
+            string pathname = pathnames[i];
+            if (pathname != "") { //add / to name if needed
+                string lastChar = pathname.substr(pathname.length()-1);
+                if (lastChar != PATH_SEPARATOR) { pathname += PATH_SEPARATOR; }
+            }
+            defaultPath.push_back(util.getFullPathName(pathname));
         }
-        defaultPath = util.getFullPathName(pathname);
     }
     catch(exception& e) {
         m->errorOut(e, "CurrentFile", "setDefaultPath");
@@ -273,24 +276,6 @@ void CurrentFile::setTestFilePath(string pathname)  {
     }
 }
 /*********************************************************************************************/
-void CurrentFile::setBlastPath(string pathname)  {
-    try {
-        lock_guard<std::mutex> guard(currentProtector);
-        
-        if (pathname != "") {
-            //add / to name if needed
-            string lastChar = pathname.substr(pathname.length()-1);
-            if (lastChar != PATH_SEPARATOR) { pathname += PATH_SEPARATOR; }
-        }
-        blastPath = util.getFullPathName(pathname);
-        
-    }
-    catch(exception& e) {
-        m->errorOut(e, "CurrentFile", "setBlastPath");
-        exit(1);
-    }
-}
-/*********************************************************************************************/
 void CurrentFile::setHomePath(string pathname)  {
     try {
         lock_guard<std::mutex> guard(currentProtector);
@@ -333,16 +318,19 @@ void CurrentFile::setPaths(vector<string> pathVariables)  {
     }
 }
 /*********************************************************************************************/
-void CurrentFile::setToolsPath(string pathname)  {
+void CurrentFile::setToolsPath(vector<string> pathnames)  {
     try {
         lock_guard<std::mutex> guard(currentProtector);
         
-        if (pathname != "") {
-            //add / to name if needed
-            string lastChar = pathname.substr(pathname.length()-1);
-            if (lastChar != PATH_SEPARATOR) { pathname += PATH_SEPARATOR; }
+        toolsPath.clear();
+        for (int i = 0; i < pathnames.size(); i++) {
+            string pathname = pathnames[i];
+            if (pathname != "") { //add / to name if needed
+                string lastChar = pathname.substr(pathname.length()-1);
+                if (lastChar != PATH_SEPARATOR) { pathname += PATH_SEPARATOR; }
+            }
+            toolsPath.push_back(util.getFullPathName(pathname));
         }
-        toolsPath = util.getFullPathName(pathname);
         
     }
     catch(exception& e) {
@@ -350,6 +338,58 @@ void CurrentFile::setToolsPath(string pathname)  {
         exit(1);
     }
 }
-
-
+/*********************************************************************************************/
+void CurrentFile::setInputDir(vector<string> pathnames)  {
+    try {
+        lock_guard<std::mutex> guard(currentProtector);
+        
+        inputDir.clear();
+        for (int i = 0; i < pathnames.size(); i++) {
+            string pathname = pathnames[i];
+            if (pathname != "") { //add / to name if needed
+                string lastChar = pathname.substr(pathname.length()-1);
+                if (lastChar != PATH_SEPARATOR) { pathname += PATH_SEPARATOR; }
+            }
+            inputDir.push_back(util.getFullPathName(pathname));
+        }
+        
+    }
+    catch(exception& e) {
+        m->errorOut(e, "CurrentFile", "setToolsPath");
+        exit(1);
+    }
+}
+/*********************************************************************************************/
+//locations[0] = inputdir paths, locations[1] = outputdirPaths, locations[2] = mothur's exe path, locations[3] = mothur tools paths, locations[4] = mothur_files paths
+vector< vector<string> > CurrentFile::getLocations()  {
+    try {
+        lock_guard<std::mutex> guard(currentProtector);
+        
+        vector< vector<string> > locations;
+        
+        //allows for multiple locations, order matters
+        locations.push_back(inputDir);
+        
+        vector<string> outputDirs; outputDirs.push_back(outputDir);
+        locations.push_back(outputDirs);
+        
+        vector<string> mothurHome; mothurHome.push_back(mothurProgramPath);
+        locations.push_back(mothurHome);
+        
+        //MOTHUR_TOOLS
+        locations.push_back(toolsPath);
+        
+        //MOTHUR_FILES
+        locations.push_back(defaultPath);
+        
+        
+        return locations;
+        
+    }
+    catch(exception& e) {
+        m->errorOut(e, "CurrentFile", "setToolsPath");
+        exit(1);
+    }
+}
+//{  }
 /*********************************************************************************************/
