@@ -2,18 +2,17 @@
 //  compare.h
 //  Mothur
 //
-//  Created by Sarah Westcott on 3/4/15.
-//  Copyright (c) 2015 Schloss Lab. All rights reserved.
+//  Created by Sarah Westcott on 6/5/18.
+//  Copyright © 2018 Schloss Lab. All rights reserved.
 //
 
-#ifndef __Mothur__compare__
-#define __Mothur__compare__
+#ifndef compare_h
+#define compare_h
 
 #include "mothurout.h"
 
-
-class Compare {
-public:
+//***************************************************************************************************************
+struct Compare {
     
     Compare(){
         AA=0; AT=0; AG=0; AC=0;
@@ -38,8 +37,8 @@ public:
     string refName, queryName, sequence;
     double errorRate;
     int weight, matches, mismatches, total;
-
 };
 
+//***************************************************************************************************************
 
-#endif /* defined(__Mothur__compare__) */
+#endif /* compare_h */
