@@ -14,14 +14,14 @@
 #include "mothur.h"
 #include "calculator.h"
 
-class DistanceDB : public Database {
+class DistanceDB : public SearchDatabase {
 	
 public:
 	
 	DistanceDB();
 	~DistanceDB() { delete distCalculator; }
 	
-	void generateDB() {} //doesn't generate a search db 
+	void generateDB(){}; //doesn't generate a search db 
 	void addSequence(Sequence); 
 	string getName(int i) { return data[i].getName(); } 
 	vector<int> findClosestSequences(Sequence*, int, vector<float>&) const;  // returns indexes of n closest sequences to query
