@@ -74,7 +74,7 @@ int OptiBlastMatrix::readBlast(){
         if (!fileHandle.eof()) {
             //read in line from file
             fileHandle >> firstName >> secondName >> percentId >> numBases >> mismatch >> gap >> startQuery >> endQuery >> startRef >> endRef >> eScore >> score;
-            util.gobble(fileHandle);
+            gobble(fileHandle);
             
             currentRow = firstName;
             lengthThisSeq = numBases;
@@ -103,7 +103,7 @@ int OptiBlastMatrix::readBlast(){
                     blastSingletonIndexSwap[indexB] = indexB;
                 }
             }
-        }else { m->mothurOut("Error in your blast file, cannot read."); m->mothurOutEndLine(); exit(1); }
+        }else { m->mothurOut("Error in your blast file, cannot read.\n");  exit(1); }
         
         
         while(fileHandle){  //let's assume it's a triangular matrix...
@@ -112,7 +112,7 @@ int OptiBlastMatrix::readBlast(){
             
             //read in line from file
             fileHandle >> firstName >> secondName >> percentId >> numBases >> mismatch >> gap >> startQuery >> endQuery >> startRef >> endRef >> eScore >> score;
-            util.gobble(fileHandle);
+            gobble(fileHandle);
             
             string temp = firstName + secondName; //to check if this file has repeat lines, ie. is this a blast instead of a blscreen file
             
@@ -268,8 +268,7 @@ int OptiBlastMatrix::readBlast(){
         }
         overlapSingleton.clear();
         
-        ifstream in;
-        util.openInputFile(distFile, in);
+        ifstream in; util.openInputFile(distFile, in);
         
         dists.resize(nameAssignment.size());
         closeness.resize(nonSingletonCount);
@@ -288,7 +287,7 @@ int OptiBlastMatrix::readBlast(){
         if (!in.eof()) {
             //read in line from file
             in >> firstName >> secondName >> percentId >> numBases >> mismatch >> gap >> startQuery >> endQuery >> startRef >> endRef >> eScore >> score;
-            util.gobble(fileHandle);
+            gobble(fileHandle);
             
             currentRow = firstName;
             lengthThisSeq = numBases;
@@ -329,7 +328,7 @@ int OptiBlastMatrix::readBlast(){
                     overlapNameMap[newB] = secondName;
                 }
             }
-        }else { m->mothurOut("Error in your blast file, cannot read."); m->mothurOutEndLine(); exit(1); }
+        }else { m->mothurOut("Error in your blast file, cannot read.\n");  exit(1); }
         
         
         while(in){  //let's assume it's a triangular matrix...
@@ -338,7 +337,7 @@ int OptiBlastMatrix::readBlast(){
             
             //read in line from file
             in >> firstName >> secondName >> percentId >> numBases >> mismatch >> gap >> startQuery >> endQuery >> startRef >> endRef >> eScore >> score;
-            util.gobble(fileHandle);
+            gobble(fileHandle);
             
             string temp = firstName + secondName; //to check if this file has repeat lines, ie. is this a blast instead of a blscreen file
             
@@ -511,14 +510,13 @@ int OptiBlastMatrix::readBlastNames(map<string, long long>& nameAssignment) {
         string name, hold, prevName;
         int num = 0;
         
-        ifstream in;
-        Utils util; util.openInputFile(distFile, in);
+        ifstream in; Utils util; util.openInputFile(distFile, in);
         
         //read first line
         in >> prevName;
         
         for (int i = 0; i < 11; i++) {  in >> hold;  }
-        util.gobble(in);
+        gobble(in);
         
         //save name in nameMap
         nameAssignment[prevName] = num; num++;
@@ -531,7 +529,7 @@ int OptiBlastMatrix::readBlastNames(map<string, long long>& nameAssignment) {
             in >> name;
             
             for (int i = 0; i < 11; i++) {  in >> hold;  }
-            util.gobble(in);
+            gobble(in);
             
             //is this a new name?
             if (name != prevName) {
