@@ -14,14 +14,6 @@
 #include "sharedordervector.h"
 
 
-/***********************************************************************/
-
-//SharedListVector::SharedListVector() : DataVector(), maxRank(0), numBins(0), numSeqs(0){ groupmap = NULL; countTable = NULL; fillGroups = true; }
-
-/***********************************************************************/
-
-//SharedListVector::SharedListVector(int n):	DataVector(), data(n, "") , maxRank(0), numBins(0), numSeqs(0){ groupmap = NULL; countTable = NULL; fillGroups = true;  }
-
 /***********************************************************************/
 SharedListVector::SharedListVector(ifstream& f, vector<string>& userGroups, string& previousLabel, string& labelTag) : DataVector(), maxRank(0), numBins(0), numSeqs(0) {
 	try {
@@ -31,7 +23,7 @@ SharedListVector::SharedListVector(ifstream& f, vector<string>& userGroups, stri
         
         CurrentFile* current = CurrentFile::getInstance();
         groupMode = current->getGroupMode();
-        groupmap = NULL; countTable = NULL;
+        groupmap = nullptr; countTable = nullptr;
 		//set up groupmap for later.
         if (groupMode == "group") {
             groupmap = new GroupMap(current->getGroupFile());
@@ -55,17 +47,17 @@ SharedListVector::SharedListVector(ifstream& f, vector<string>& userGroups, stri
 			if (label == "label") {
 				
 				//gets "numOtus"
-				f >> label; util.gobble(f);
+				f >> label; gobble(f);
 				
 				//eat rest of line
-				label = util.getline(f); util.gobble(f);
+				label = util.getline(f); gobble(f);
 				
 				//parse labels to save
 				istringstream iStringStream(label);
 				while(!iStringStream.eof()){
 					if (m->getControl_pressed()) { break; }
 					string temp;
-					iStringStream >> temp;  util.gobble(iStringStream);
+					iStringStream >> temp;  gobble(iStringStream);
                     
 					binLabels.push_back(temp);
 				}
@@ -106,7 +98,7 @@ SharedListVector::SharedListVector(ifstream& f, vector<string>& userGroups, stri
 			f >> inputData;
 			set(i, inputData);
 		}
-		util.gobble(f);
+		gobble(f);
 	}
 	catch(exception& e) {
 		m->errorOut(e, "SharedListVector", "SharedListVector");
@@ -381,7 +373,7 @@ SharedRAbundVectors* SharedListVector::getSharedRAbundVector() {
 			}
 		}
         
-        SharedRAbundVectors* shared = new SharedRAbundVectors();
+        SharedRAbundVectors* shared = new SharedRAbundVectors(otuTag);
         for (int j = 0; j < lookup.size(); j++) {  shared->push_back(lookup[j]);  }
         shared->setOTUNames(binLabels);
         shared->eliminateZeroOTUS();
@@ -398,7 +390,7 @@ SharedRAbundFloatVectors* SharedListVector::getSharedRAbundFloatVector() {
     try {
         SharedRAbundVectors* shared = getSharedRAbundVector();
         vector<SharedRAbundFloatVector*> thisLookup = shared->getSharedRAbundFloatVectors();
-        SharedRAbundFloatVectors* sharedFloat = new SharedRAbundFloatVectors();
+        SharedRAbundFloatVectors* sharedFloat = new SharedRAbundFloatVectors(otuTag);
         for (int j = 0; j < thisLookup.size(); j++) {  sharedFloat->push_back(thisLookup[j]);  }
         return sharedFloat;
     }
@@ -410,11 +402,11 @@ SharedRAbundFloatVectors* SharedListVector::getSharedRAbundFloatVector() {
 
 /***********************************************************************/
 
-OrderVector SharedListVector::getOrderVector(map<string,int>* orderMap = NULL){
+OrderVector SharedListVector::getOrderVector(map<string,int>* orderMap = nullptr){
 	
 	try {
         Utils util;
-		if(orderMap == NULL){
+		if(orderMap == nullptr){
 			OrderVector ov;
 		
 			for(int i=0;i<data.size();i++){
