@@ -18,7 +18,7 @@ SharedRAbundVectors::SharedRAbundVectors(ifstream& f, vector<string>& userGroups
         string holdLabel, groupN;
         int numUserGroups = userGroups.size();
         
-        for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != NULL) { delete lookup[i];  lookup[i] = NULL; } }  lookup.clear();
+        for (int i = 0; i < lookup.size(); i++) {  if (lookup[i] != nullptr) { delete lookup[i];  lookup[i] = nullptr; } }  lookup.clear();
         
         //are we at the beginning of the file??
         if (nextLabel == "") {
@@ -27,20 +27,20 @@ SharedRAbundVectors::SharedRAbundVectors(ifstream& f, vector<string>& userGroups
             //is this a shared file that has headers
             if (label == "label") {
                 //gets "group"
-                f >> label; util.gobble(f);
+                f >> label; gobble(f);
                 
                 //gets "numOtus"
-                f >> label; util.gobble(f);
+                f >> label; gobble(f);
                 
                 //eat rest of line
-                label = util.getline(f); util.gobble(f);
+                label = util.getline(f); gobble(f);
                 
                 //parse labels to save
                 istringstream iStringStream(label);
                 while(!iStringStream.eof()){
                     if (m->getControl_pressed()) { break; }
                     string temp;
-                    iStringStream >> temp;  util.gobble(iStringStream);
+                    iStringStream >> temp;  gobble(iStringStream);
                     
                     currentLabels.push_back(temp);
                 }
@@ -104,7 +104,7 @@ SharedRAbundVectors::SharedRAbundVectors(ifstream& f, vector<string>& userGroups
             SharedRAbundVector* temp = new SharedRAbundVector(f, label, groupN, numBins);
             push_back(temp);
         } else { util.getline(f); }
-        util.gobble(f);
+        gobble(f);
 
         
         if (!(f.eof())) {
@@ -128,7 +128,7 @@ SharedRAbundVectors::SharedRAbundVectors(ifstream& f, vector<string>& userGroups
                 SharedRAbundVector* temp = new SharedRAbundVector(f, label, groupN, numBins);
                 push_back(temp);
             } else { util.getline(f); }
-            util.gobble(f);
+            gobble(f);
 
             if (f.eof() != true) { f >> nextLabel; }
         }
@@ -250,7 +250,7 @@ void SharedRAbundVectors::printHeaders(ostream& output, bool& printSharedHeaders
         if (printSharedHeaders) {
             getOTUNames();
         
-            output << "label\tGroup\tnumOtus";
+            output << "label\tGroup\tnum" + otuTag + "s"; 
             for (int i = 0; i < numBins; i++) { output  << '\t' << currentLabels[i]; } output << endl;
         
             printSharedHeaders = false;
@@ -529,7 +529,7 @@ void SharedRAbundVectors::removeGroups(vector<string> g){
             //if this sharedrabund is not from a group the user wants then delete it.
             if (util.inUsersGroups((*it)->getGroup(), g)) {
                 remove = true;
-                delete (*it); (*it) = NULL;
+                delete (*it); (*it) = nullptr;
                 it = lookup.erase(it);
             }else { ++it; }
         }
@@ -552,7 +552,7 @@ int SharedRAbundVectors::removeGroups(int minSize, bool silent){
         for (vector<SharedRAbundVector*>::iterator it = lookup.begin(); it != lookup.end();) {
             if ((*it)->getNumSeqs() < minSize) {
                 if (!silent) { m->mothurOut((*it)->getGroup() + " contains " + toString((*it)->getNumSeqs()) + ". Eliminating.\n");  }
-                delete (*it); (*it) = NULL;
+                delete (*it); (*it) = nullptr;
                 it = lookup.erase(it);
                 remove = true;
             }else {
