@@ -19,17 +19,17 @@
  */
 
 #include "mothur.h"
-#include "database.hpp"
+#include "searchdatabase.hpp"
 #include "suffixtree.hpp"
 
-class SuffixDB : public Database {
+class SuffixDB : public SearchDatabase {
 	
 public:
 	SuffixDB(int);
 	SuffixDB();
 	~SuffixDB();
 	
-	void generateDB() {}; //adding sequences generates the db
+	void generateDB(){}; //adding sequences generates the db
 	void addSequence(Sequence);
 	vector<int> findClosestSequences(Sequence*, int, vector<float>&) const;
 
