@@ -29,9 +29,9 @@ class GotohOverlap : public Alignment {
 	
 public:
 	GotohOverlap(float, float, float, float, int);
-	void align(string, string);
+	void align(string, string, bool createBaseMap=false);
 	
-	~GotohOverlap() {}
+	~GotohOverlap() = default;
 	
 private:
 	float gapOpen;
