@@ -12,6 +12,8 @@
 #include "calculator.h"
 #include "utils.hpp"
 
+class SharedRAbundVectors;
+
 /***********************************************************************/
 
 class HeatMapSim {
@@ -20,7 +22,7 @@ class HeatMapSim {
 		HeatMapSim(string, string, int);
 		~HeatMapSim(){};
 	
-		vector<string> getPic(vector<SharedRAbundVector*>, vector<Calculator*>, vector<string>);
+		vector<string> getPic(SharedRAbundVectors*&, vector<Calculator*>, vector<string>);
 		string getPic(vector< vector<double> >, vector<string>);
 
 	private:
