@@ -46,7 +46,7 @@ InputData::InputData(string fName, string orderFileName, string f) : format(f){
 			ofHandle >> name;
 			orderMap[name] = count;
 			count++;
-			util.gobble(ofHandle);
+			gobble(ofHandle);
 		}
 		ofHandle.close();
 	
@@ -67,18 +67,18 @@ ListVector* InputData::getListVector(){
 		if(!fileHandle.eof()){
 			if(format == "list") {
 				list = new ListVector(fileHandle, nextDistanceLabel, otuTag);
-                if (list != NULL) {
+                if (list != nullptr) {
                     //pass labels to others distances in file
                     if (currentLabels.size() == 0) { currentLabels = list->getLabels(); }
                     else { list->setLabels(currentLabels);  }
                 }
-			}else{ list = NULL;  }
+			}else{ list = nullptr;  }
 					
-			util.gobble(fileHandle);
+			gobble(fileHandle);
 			return list;
 		}
 		else{
-			return NULL;
+			return nullptr;
 		}
 	}
 	catch(exception& e) {
@@ -90,8 +90,7 @@ ListVector* InputData::getListVector(){
 /***********************************************************************/
 ListVector* InputData::getListVector(string label){
 	try {
-		ifstream in;
-		util.openInputFile(filename, in);
+		ifstream in; util.openInputFile(filename, in);
         nextDistanceLabel = "";
 		
 		if(in){
@@ -103,7 +102,7 @@ ListVector* InputData::getListVector(string label){
 					list = new ListVector(in, nextDistanceLabel, otuTag);
 					nextDistanceLabel = list->getLabel();
                     
-                    if (list != NULL) {
+                    if (list != nullptr) {
                         //pass labels to others distances in file
                         if (currentLabels.size() == 0) { currentLabels = list->getLabels(); }
                         else { list->setLabels(currentLabels);  }
@@ -113,15 +112,15 @@ ListVector* InputData::getListVector(string label){
 					if (nextDistanceLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete list;	}
-					util.gobble(in);
+					gobble(in);
 				}
-			}else{ list = NULL;  }
+			}else{ list = nullptr;  }
 			
 			in.close();
 			return list;
 		}
 		else{
-			return NULL;
+			return nullptr;
 		}
 	}
 	catch(exception& e) {
@@ -142,27 +141,24 @@ ListVector* InputData::getListVector(string label, bool resetFP){
 			
 				while (fileHandle.eof() != true) {
 					
-					list = new ListVector(fileHandle, nextDistanceLabel, otuTag); util.gobble(fileHandle);
+					list = new ListVector(fileHandle, nextDistanceLabel, otuTag); gobble(fileHandle);
 					nextDistanceLabel = list->getLabel();
                     
-                     if (list != NULL) {
+                     if (list != nullptr) {
                          //pass labels to others distances in file
                          if (currentLabels.size() == 0) { currentLabels = list->getLabels(); }
                          else { list->setLabels(currentLabels);  }
                      }
 					
-					//if you are at the last label
-					if (nextDistanceLabel == label) {  break;  }
-					//so you don't loose this memory
-					else {	delete list;	}
+					//if you are at the label you want
+                    if (nextDistanceLabel == label) {  return list;  }
+					else {	delete list;	} //so you don't loose this memory
 				}
-			}else{ list = NULL;  }
-		
-			return list;
-		}
-		else{
-			return NULL;
+                
+			}else{ return nullptr;   }
 		}
+        
+        return nullptr;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "InputData", "getListVector");
@@ -177,18 +173,18 @@ SharedListVector* InputData::getSharedListVector(){
 		if(fileHandle){
 			if (format == "shared")  {
 				SharedList = new SharedListVector(fileHandle, groups, nextDistanceLabel, otuTag);
-                if (SharedList != NULL) {
+                if (SharedList != nullptr) {
                     //pass labels to others distances in file
                     if (currentLabels.size() == 0) { currentLabels = SharedList->getLabels(); }
                     else { SharedList->setLabels(currentLabels);  }
                 }
 
-			}else{ SharedList = NULL;  }
+			}else{ SharedList = nullptr;  }
 					
-			util.gobble(fileHandle);
+			gobble(fileHandle);
 			return SharedList;
 		}
-		else{ return NULL; }
+		else{ return nullptr; }
 	}
 	catch(exception& e) {
 		m->errorOut(e, "InputData", "getSharedListVector");
@@ -199,9 +195,9 @@ SharedListVector* InputData::getSharedListVector(){
 
 SharedListVector* InputData::getSharedListVector(string label){
 	try {
-		ifstream in;
+		
 		string  thisLabel;
-		util.openInputFile(filename, in);
+        ifstream in; util.openInputFile(filename, in);
         nextDistanceLabel = "";
 		
 		if(in){
@@ -213,7 +209,7 @@ SharedListVector* InputData::getSharedListVector(string label){
 					SharedList = new SharedListVector(in, groups, nextDistanceLabel, otuTag);
 					thisLabel = SharedList->getLabel();
                     
-                    if (SharedList != NULL) {
+                    if (SharedList != nullptr) {
                         //pass labels to others distances in file
                         if (currentLabels.size() == 0) { currentLabels = SharedList->getLabels(); }
                         else { SharedList->setLabels(currentLabels);  }
@@ -222,15 +218,15 @@ SharedListVector* InputData::getSharedListVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete SharedList;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
-			}else{ SharedList = NULL;  }
+			}else{ SharedList = nullptr;  }
 				
 			in.close();
 			return SharedList;
 			
-		}else{ return NULL; }
+		}else{ return nullptr; }
 	}
 	catch(exception& e) {
 		m->errorOut(e, "InputData", "getSharedListVector");
@@ -247,14 +243,14 @@ SharedOrderVector* InputData::getSharedOrderVector(){
 		if(fileHandle){
 			if (format == "sharedfile")  {
 				SharedOrder = new SharedOrderVector(fileHandle, groups, nextDistanceLabel);
-                if (SharedOrder->getNumBins() == 0) { delete SharedOrder; SharedOrder =  NULL; } //no valid groups
-			}else{ SharedOrder = NULL;  }
+                if (SharedOrder->getNumBins() == 0) { delete SharedOrder; SharedOrder =  nullptr; } //no valid groups
+			}else{ SharedOrder = nullptr;  }
 				
-			util.gobble(fileHandle);
+			gobble(fileHandle);
 			return SharedOrder;
 			
 		}else{
-			return NULL;
+			return nullptr;
 		}
 	}
 	catch(exception& e) {
@@ -267,9 +263,8 @@ SharedOrderVector* InputData::getSharedOrderVector(){
 
 SharedOrderVector* InputData::getSharedOrderVector(string label){
 	try {
-		ifstream in;
 		string  thisLabel;
-		util.openInputFile(filename, in);
+        ifstream in; util.openInputFile(filename, in);
         nextDistanceLabel = "";
 		
 		if(in){
@@ -280,22 +275,22 @@ SharedOrderVector* InputData::getSharedOrderVector(string label){
 					
 					SharedOrder = new SharedOrderVector(in, groups, nextDistanceLabel);
 					thisLabel = SharedOrder->getLabel();
-                    if (SharedOrder->getNumBins() == 0) { delete SharedOrder; SharedOrder =  NULL; break; } //no valid groups
+                    if (SharedOrder->getNumBins() == 0) { delete SharedOrder; SharedOrder =  nullptr; break; } //no valid groups
 					
 					//if you are at the last label
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete SharedOrder;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
-			}else{ SharedOrder = NULL;  }
+			}else{ SharedOrder = nullptr;  }
 				
 			in.close();
 			return SharedOrder;
 			
 		}else{
-			return NULL;
+			return nullptr;
 		}
 	}
 	catch(exception& e) {
@@ -327,7 +322,7 @@ OrderVector* InputData::getOrderVector(){
 				input = new SAbundVector(fileHandle);
 			}
 						
-			util.gobble(fileHandle);
+			gobble(fileHandle);
 			
 			output = new OrderVector();	
 			*output = (input->getOrderVector());
@@ -335,7 +330,7 @@ OrderVector* InputData::getOrderVector(){
 			return output;
 		}
 		else{
-			return NULL;
+			return nullptr;
 		}
 	}
 	catch(exception& e) {
@@ -347,10 +342,8 @@ OrderVector* InputData::getOrderVector(){
 /***********************************************************************/
 OrderVector* InputData::getOrderVector(string label){
 	try {
-	
-		ifstream in;
 		string  thisLabel;
-		util.openInputFile(filename, in);
+        ifstream in; util.openInputFile(filename, in);
         nextDistanceLabel = "";
 		
 		if(in){
@@ -365,7 +358,7 @@ OrderVector* InputData::getOrderVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 			}
 			else if (format == "shared")  {
@@ -379,7 +372,7 @@ OrderVector* InputData::getOrderVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
 			}
@@ -394,7 +387,7 @@ OrderVector* InputData::getOrderVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
 			}
@@ -409,7 +402,7 @@ OrderVector* InputData::getOrderVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
 			}
@@ -424,7 +417,7 @@ OrderVector* InputData::getOrderVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 					
 				}
 
@@ -439,7 +432,7 @@ OrderVector* InputData::getOrderVector(string label){
 
 		}
 		else{
-			return NULL;
+			return nullptr;
 		}
 	}
 	catch(exception& e) {
@@ -453,17 +446,17 @@ SharedRAbundVectors* InputData::getSharedRAbundVectors(){
         if(fileHandle){
             if (format == "sharedfile")  {
                 SharedRAbundVectors* shared = new SharedRAbundVectors(fileHandle, groups, nextDistanceLabel, otuTag);
-                if (shared != NULL) {
+                if (shared != nullptr) {
                     //pass labels to others distances in file
                     if (currentLabels.size() == 0) { currentLabels = shared->getOTUNames(); }
                     else { shared->setOTUNames(currentLabels);  }
-                    if (shared->getNumBins() == 0) { delete shared; shared = NULL; } //no valid groups
+                    if (shared->getNumBins() == 0) { delete shared; shared = nullptr; } //no valid groups
                 }
                 return shared;
             }else if (format == "shared") {
                 SharedList = new SharedListVector(fileHandle, groups, nextDistanceLabel, otuTag);
                 
-                if (SharedList != NULL) {
+                if (SharedList != nullptr) {
                     //pass labels to others distances in file
                     if (currentLabels.size() == 0) { currentLabels = SharedList->getLabels(); }
                     else { SharedList->setLabels(currentLabels);  }
@@ -471,11 +464,11 @@ SharedRAbundVectors* InputData::getSharedRAbundVectors(){
                     return SharedList->getSharedRAbundVector();
                 }
             }
-            util.gobble(fileHandle);
+            gobble(fileHandle);
         }
         
         //this is created to signal to calling function that the input file is at eof
-        SharedRAbundVectors* null; null = NULL;
+        SharedRAbundVectors* null; null = nullptr;
         return null;
         
     }
@@ -488,10 +481,9 @@ SharedRAbundVectors* InputData::getSharedRAbundVectors(){
 /***********************************************************************/
 SharedRAbundVectors* InputData::getSharedRAbundVectors(string label){
 	try {
-		ifstream in;
 		string  thisLabel;
 		
-		util.openInputFile(filename, in);
+        ifstream in; util.openInputFile(filename, in);
 		nextDistanceLabel = "";
 	
 		if(in){
@@ -499,10 +491,10 @@ SharedRAbundVectors* InputData::getSharedRAbundVectors(string label){
 				while (!in.eof()) {
 					
 					SharedRAbundVectors* SharedRAbund = new SharedRAbundVectors(in, groups, nextDistanceLabel, otuTag);
-					if (SharedRAbund != NULL) {
+					if (SharedRAbund != nullptr) {
 						thisLabel = SharedRAbund->getLabel();
                         
-                        if (SharedRAbund->getNumBins() == 0) { delete SharedRAbund; SharedRAbund = NULL; break; } //no valid groups
+                        if (SharedRAbund->getNumBins() == 0) { delete SharedRAbund; SharedRAbund = nullptr; break; } //no valid groups
                         
                         //pass labels to others distances in file
                         if (currentLabels.size() == 0) { currentLabels = SharedRAbund->getOTUNames(); }
@@ -515,7 +507,7 @@ SharedRAbundVectors* InputData::getSharedRAbundVectors(string label){
 							delete SharedRAbund;
 						}
 					}else{  break;  }
-					util.gobble(in);
+					gobble(in);
 					
 				}
 			}else if (format == "shared") {
@@ -523,7 +515,7 @@ SharedRAbundVectors* InputData::getSharedRAbundVectors(string label){
 					
 					SharedList = new SharedListVector(in, groups, nextDistanceLabel, otuTag);
 					
-					if (SharedList != NULL) {
+					if (SharedList != nullptr) {
 						thisLabel = SharedList->getLabel();
                         //pass labels to others distances in file
                         if (currentLabels.size() == 0) { currentLabels = SharedList->getLabels(); }
@@ -536,7 +528,7 @@ SharedRAbundVectors* InputData::getSharedRAbundVectors(string label){
 							delete SharedList;
 						}
 					}else{  break;  }
-					util.gobble(in);
+					gobble(in);
 					
 				}
 			
@@ -544,7 +536,7 @@ SharedRAbundVectors* InputData::getSharedRAbundVectors(string label){
 		}
 				
 		//this is created to signal to calling function that the input file is at eof
-		SharedRAbundVectors* null;  null = (NULL);
+		SharedRAbundVectors* null;  null = (nullptr);
 		in.close();
 		return null;
 	
@@ -562,7 +554,7 @@ SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(){
 		if(fileHandle){
 			if (format == "relabund")  {
 				SharedRAbundFloatVectors* SharedRelAbund = new SharedRAbundFloatVectors(fileHandle, groups, nextDistanceLabel, otuTag);
-                if (SharedRelAbund->getNumBins() == 0) { delete SharedRelAbund; SharedRelAbund = NULL;  } //no valid groups
+                if (SharedRelAbund->getNumBins() == 0) { delete SharedRelAbund; SharedRelAbund = nullptr;  } //no valid groups
                 else { //pass labels to others distances in file
                     if (currentLabels.size() == 0) { currentLabels = SharedRelAbund->getOTUNames(); }
                     else { SharedRelAbund->setOTUNames(currentLabels);  }
@@ -570,7 +562,7 @@ SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(){
                 return SharedRelAbund;
 			}else if (format == "sharedfile")  {
 				SharedRAbundVectors* SharedRAbund = new SharedRAbundVectors(fileHandle, groups, nextDistanceLabel, otuTag);
-				if (SharedRAbund != NULL) {
+				if (SharedRAbund != nullptr) {
                     //pass labels to others distances in file
                     if (currentLabels.size() == 0) { currentLabels = SharedRAbund->getOTUNames(); }
                     else { SharedRAbund->setOTUNames(currentLabels);  }
@@ -584,11 +576,11 @@ SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(){
 				}
 						
 			}
-			util.gobble(fileHandle);
+			gobble(fileHandle);
 		}
 				
 		//this is created to signal to calling function that the input file is at eof
-		SharedRAbundFloatVectors* null;  null = (NULL);
+		SharedRAbundFloatVectors* null;  null = (nullptr);
 		return null;
 	}
 	catch(exception& e) {
@@ -599,10 +591,9 @@ SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(){
 /***********************************************************************/
 SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(string label){
 	try {
-		ifstream in;
 		string  thisLabel;
 		
-		util.openInputFile(filename, in);
+        ifstream in; util.openInputFile(filename, in);
 		nextDistanceLabel = "";
 		
 		if(in){
@@ -610,10 +601,10 @@ SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(string label){
 				while (!in.eof()) {
 					
 					SharedRAbundFloatVectors* SharedRelAbund = new SharedRAbundFloatVectors(in, groups, nextDistanceLabel, otuTag);
-					if (SharedRelAbund != NULL) {
+					if (SharedRelAbund != nullptr) {
 						thisLabel = SharedRelAbund->getLabel();
                         
-                        if (SharedRelAbund->getNumBins() == 0) { delete SharedRelAbund; SharedRelAbund = NULL; break;  } //no valid groups
+                        if (SharedRelAbund->getNumBins() == 0) { delete SharedRelAbund; SharedRelAbund = nullptr; break;  } //no valid groups
                         
                         //pass labels to others distances in file
                         if (currentLabels.size() == 0) { currentLabels = SharedRelAbund->getOTUNames(); }
@@ -622,13 +613,13 @@ SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(string label){
 						if (thisLabel == label) {  in.close(); return SharedRelAbund;  }
 						else { delete SharedRelAbund; }
 					}else{  break;  }
-					util.gobble(in);
+					gobble(in);
 				}
 			}else if (format == "sharedfile")  {
 				while (!in.eof()) {
 					
 					SharedRAbundVectors* SharedRAbund = new SharedRAbundVectors(in, groups, nextDistanceLabel, otuTag);
-					if (SharedRAbund != NULL) {
+					if (SharedRAbund != nullptr) {
 						thisLabel = SharedRAbund->getLabel();
                         
                         //pass labels to others distances in file
@@ -646,14 +637,14 @@ SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(string label){
                             return SharedRelAbund;
 						}else { delete SharedRAbund; }
 					}else{  break;  }
-					util.gobble(in);
+					gobble(in);
 				}
 			}	
 		}
 		
 				
 		//this is created to signal to calling function that the input file is at eof
-		SharedRAbundFloatVectors* null;  null = (NULL);
+		SharedRAbundFloatVectors* null;  null = (nullptr);
 		in.close();
 		return null;
 	
@@ -670,18 +661,18 @@ SharedCLRVectors* InputData::getSharedCLRVectors(){
         if(fileHandle){
             if (format == "clrfile")  {
                 SharedCLRVectors* SharedCLR = new SharedCLRVectors(fileHandle, groups, nextDistanceLabel, otuTag);
-                if (SharedCLR->getNumBins() == 0) { delete SharedCLR; SharedCLR = NULL;  } //no valid groups
+                if (SharedCLR->getNumBins() == 0) { delete SharedCLR; SharedCLR = nullptr;  } //no valid groups
                 else { //pass labels to others distances in file
                     if (currentLabels.size() == 0) { currentLabels = SharedCLR->getOTUNames(); }
                     else { SharedCLR->setOTUNames(currentLabels);  }
                 }
                 return SharedCLR;
             }
-            util.gobble(fileHandle);
+            gobble(fileHandle);
         }
                 
         //this is created to signal to calling function that the input file is at eof
-        SharedCLRVectors* null;  null = (NULL);
+        SharedCLRVectors* null;  null = (nullptr);
         return null;
     }
     catch(exception& e) {
@@ -692,10 +683,9 @@ SharedCLRVectors* InputData::getSharedCLRVectors(){
 /***********************************************************************/
 SharedCLRVectors* InputData::getSharedCLRVectors(string label){
     try {
-        ifstream in;
         string  thisLabel;
         
-        util.openInputFile(filename, in);
+        ifstream in; util.openInputFile(filename, in);
         nextDistanceLabel = "";
         
         if(in){
@@ -703,10 +693,10 @@ SharedCLRVectors* InputData::getSharedCLRVectors(string label){
                 while (!in.eof()) {
                     
                     SharedCLRVectors* SharedCLR = new SharedCLRVectors(in, groups, nextDistanceLabel, otuTag);
-                    if (SharedCLR != NULL) {
+                    if (SharedCLR != nullptr) {
                         thisLabel = SharedCLR->getLabel();
                         
-                        if (SharedCLR->getNumBins() == 0) { delete SharedCLR; SharedCLR = NULL; break;  } //no valid groups
+                        if (SharedCLR->getNumBins() == 0) { delete SharedCLR; SharedCLR = nullptr; break;  } //no valid groups
                         
                         //pass labels to others distances in file
                         if (currentLabels.size() == 0) { currentLabels = SharedCLR->getOTUNames(); }
@@ -715,13 +705,13 @@ SharedCLRVectors* InputData::getSharedCLRVectors(string label){
                         if (thisLabel == label) {  in.close(); return SharedCLR;  }
                         else { delete SharedCLR; }
                     }else{  break;  }
-                    util.gobble(in);
+                    gobble(in);
                 }
             }
         }
         
         //this is created to signal to calling function that the input file is at eof
-        SharedCLRVectors* null;  null = (NULL);
+        SharedCLRVectors* null;  null = (nullptr);
         in.close();
         return null;
     
@@ -751,7 +741,7 @@ SAbundVector* InputData::getSAbundVector(){
 			else if(format == "sabund"){
 				input = new SAbundVector(fileHandle);
 			}					
-			util.gobble(fileHandle);
+			gobble(fileHandle);
 
 			sabund = new SAbundVector();
 			*sabund = (input->getSAbundVector());
@@ -759,7 +749,7 @@ SAbundVector* InputData::getSAbundVector(){
 			return sabund;
 		}
 		else{
-			return NULL;
+			return nullptr;
 		}
 	}
 	catch(exception& e) {
@@ -770,10 +760,8 @@ SAbundVector* InputData::getSAbundVector(){
 /***********************************************************************/
 SAbundVector* InputData::getSAbundVector(string label){
 	try {
-	
-		ifstream in;
 		string  thisLabel;
-		util.openInputFile(filename, in);
+        ifstream in; util.openInputFile(filename, in);
         nextDistanceLabel = "";
 		
 		if(in){
@@ -788,7 +776,7 @@ SAbundVector* InputData::getSAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 			}
 			else if (format == "shared")  {
@@ -802,7 +790,7 @@ SAbundVector* InputData::getSAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
 			}
@@ -817,7 +805,7 @@ SAbundVector* InputData::getSAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
 			}
@@ -832,7 +820,7 @@ SAbundVector* InputData::getSAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
 			}
@@ -847,7 +835,7 @@ SAbundVector* InputData::getSAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 					
 				}
 
@@ -862,7 +850,7 @@ SAbundVector* InputData::getSAbundVector(string label){
 
 		}
 		else{
-			return NULL;
+			return nullptr;
 		}
 	}
 	catch(exception& e) {
@@ -891,14 +879,14 @@ RAbundVector* InputData::getRAbundVector(){
 				input = new SAbundVector(fileHandle);
             }else if (format == "sharedfile")  {
                 SharedRAbundVectors* shared = new SharedRAbundVectors(fileHandle, groups, nextDistanceLabel, otuTag);
-                if (shared != NULL) {
+                if (shared != nullptr) {
                     //pass labels to others distances in file
                     if (currentLabels.size() == 0) { currentLabels = shared->getOTUNames(); }
                     else { shared->setOTUNames(currentLabels);  }
-                    if (shared->getNumBins() == 0) { delete shared; shared = NULL;  return NULL; } //no valid groups
+                    if (shared->getNumBins() == 0) { delete shared; shared = nullptr;  return nullptr; } //no valid groups
                 }
                 
-                util.gobble(fileHandle);
+                gobble(fileHandle);
                 
                 rabund = new RAbundVector();
                 *rabund = (shared->getRAbundVector());
@@ -907,7 +895,7 @@ RAbundVector* InputData::getRAbundVector(){
                 return rabund;
             }
 
-			util.gobble(fileHandle);
+			gobble(fileHandle);
             
 			rabund = new RAbundVector();
 			*rabund = (input->getRAbundVector());
@@ -916,7 +904,7 @@ RAbundVector* InputData::getRAbundVector(){
 			return rabund;
 		}
 		else{
-			return NULL;
+			return nullptr;
 		}
 	}
 	catch(exception& e) {
@@ -926,11 +914,9 @@ RAbundVector* InputData::getRAbundVector(){
 }
 /***********************************************************************/
 RAbundVector* InputData::getRAbundVector(string label){
-	try {
-	
-		ifstream in;
+	try { 
 		string  thisLabel;
-		util.openInputFile(filename, in);
+        ifstream in; util.openInputFile(filename, in);
         nextDistanceLabel = "";
 		
 		if(in){
@@ -946,7 +932,7 @@ RAbundVector* InputData::getRAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 			}
 			else if (format == "shared")  {
@@ -961,7 +947,7 @@ RAbundVector* InputData::getRAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
 			}
@@ -976,7 +962,7 @@ RAbundVector* InputData::getRAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
 			}
@@ -991,7 +977,7 @@ RAbundVector* InputData::getRAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 				}
 
 			}
@@ -1006,7 +992,7 @@ RAbundVector* InputData::getRAbundVector(string label){
 					if (thisLabel == label) {  break;  }
 					//so you don't loose this memory
 					else {	delete input;	}
-					util.gobble(in);
+					gobble(in);
 					
 				}
 
@@ -1014,10 +1000,10 @@ RAbundVector* InputData::getRAbundVector(string label){
                 while (!in.eof()) {
                     
                     SharedRAbundVectors* shared = new SharedRAbundVectors(in, groups, nextDistanceLabel, otuTag);
-                    if (shared != NULL) {
+                    if (shared != nullptr) {
                         thisLabel = shared->getLabel();
                         
-                        if (shared->getNumBins() == 0) { delete shared; shared = NULL; in.close(); return NULL; } //no valid groups
+                        if (shared->getNumBins() == 0) { delete shared; shared = nullptr; in.close(); return nullptr; } //no valid groups
                         
                         //pass labels to others distances in file
                         if (currentLabels.size() == 0) { currentLabels = shared->getOTUNames(); }
@@ -1035,8 +1021,8 @@ RAbundVector* InputData::getRAbundVector(string label){
                             return rabund;
                         }
                         else { delete shared;  }
-                    }else{ in.close(); return NULL;  }
-                    util.gobble(in);
+                    }else{ in.close(); return nullptr;  }
+                    gobble(in);
                 }
                 
             }
@@ -1050,7 +1036,7 @@ RAbundVector* InputData::getRAbundVector(string label){
 			return rabund;
 		}
 		else{
-			return NULL;
+			return nullptr;
 		}
 	}
 	catch(exception& e) {
