@@ -24,7 +24,7 @@ MothurMetastats::MothurMetastats(double t, int n) {
 	}	
 }
 /***********************************************************/
-MothurMetastats::~MothurMetastats() {}
+MothurMetastats::~MothurMetastats() = default;
 /***********************************************************/
  //main metastats function
 int MothurMetastats::runMetastats(string outputFileName, vector< vector<double> >& data, int secGroupingStart, vector<string> currentLabels, bool fillProps) {
@@ -210,7 +210,7 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
         
         // And now we write the files to a text file.
 		struct tm *local;
-		time_t t; t = time(NULL);
+		time_t t; t = time(nullptr);
 		local = localtime(&t);
 		
 		ofstream out;
@@ -280,7 +280,7 @@ vector<double> MothurMetastats::permuted_pvalues(vector< vector<double> >& Imatr
                 //number of cleanedpermuted_ttests greater than tstat[i]
                 int numGreater = 0;
                 for (int j = 0; j < numPermutations; j++) {
-                    for (int k = 0; k < hfc; k++) {
+                    for (int k = 0; k < cleanedpermuted_ttests[j].size(); k++) {
                         if (cleanedpermuted_ttests[j][k] > abs(tstats[i])) { numGreater++; }
                     }
                 }
