@@ -15,8 +15,8 @@
 /***********************************************/
 struct logger {
     
-    logger() {}
-    ~logger() {}
+    logger() = default;
+    ~logger() = default;
     
     template< class T >
     logger& operator <<( const T& o ) {
@@ -29,7 +29,7 @@ struct logger {
         cout << m; return *this;
     }
 private:
-    std::mutex token;
+    //std::mutex token;
 };
 /***********************************************/
 
@@ -39,10 +39,8 @@ class MothurOut {
 		static MothurOut* getInstance();
     
         //logger
-        void appendLogBuffer(string); //used to store log before we establish the logfilename
         bool getDebug()                                 { return debug;                                 }
         void setDebug(bool t)                           { debug = t;                                    }
-        bool getQuietMode()                             { return quietMode;                             }
         void setQuietMode(bool t)                       { quietMode = t;                                }
         int getNumErrors()                              { return numErrors;                             }
         void resetCommandErrors()                       { control_pressed = false; numCommandErrors = 0; numCommandWarnings = 0; silenceWarnings = false;}
@@ -55,9 +53,7 @@ class MothurOut {
     
 		void mothurOut(string); //writes to cout and the logfile
 		void mothurOutEndLine(); //writes to cout and the logfile
-        void mothurOutClearBuffer();
 		void mothurOut(string, ofstream&); //writes to the ofstream, cout and the logfile
-		void mothurOutEndLine(ofstream&); //writes to the ofstream, cout and the logfile
         void mothurOutJustToScreen(string); //writes to cout
 		void mothurOutJustToLog(string);
 		void errorOut(exception&, string, string);
@@ -70,9 +66,14 @@ class MothurOut {
         void setControl_pressed(bool t)                 { control_pressed = t;              }
         bool getChangedSeqNames()                       { return changedSeqNames;           }
         void setChangedSeqNames(bool t)                 { changedSeqNames = t;              }
+        bool getChangedGroupNames()                     { return changedGroupNames;         }
+        void setChangedGroupNames(bool t)               { changedGroupNames = t;            }
         bool getExecuting()                             { return executing;                 }
         void setExecuting(bool t)                       { executing = t;                    }
     
+        vector<vector<vector<char>>> codons;
+        set<char> validAminoAcids;
+    
 	private:
 		static MothurOut* _uniqueInstance;
 		MothurOut( const MothurOut& ); // Disable copy constructor
@@ -82,6 +83,7 @@ class MothurOut {
             debug = false;
             quietMode = false;
             changedSeqNames = true;
+            changedGroupNames = true;
             silenceLog = false;
             silenceWarnings = false; //per command
             numErrors = 0; numWarnings = 0;
@@ -90,16 +92,22 @@ class MothurOut {
             logFileName = "";
             buffer = "";
             homePath = "";
+            outLog = nullptr;
             seed = std::chrono::system_clock::now().time_since_epoch().count();
+            
+            initialize(); //fills validAminoAcids and codons
 		}
 		~MothurOut();
 		
-		ofstream out;
+        void appendLogBuffer(string); //used to store log before we establish the logfilename
+        void initialize();
+
+		ofstream* outLog;
         unsigned seed;
         int numErrors, numWarnings, numCommandErrors, numCommandWarnings, maxCommandErrors, maxCommandWarnings;
         string logFileName, buffer, homePath;
         vector<string> paths;
-        bool changedSeqNames, silenceLog, silenceWarnings, control_pressed, executing, debug, quietMode;
+        bool changedSeqNames, changedGroupNames, silenceLog, silenceWarnings, control_pressed, executing, debug, quietMode;
 };
 /***********************************************/
 
