@@ -11,9 +11,8 @@ class Observable {
 	
 public:
 	virtual void registerDisplay(Display*) = 0;
-	virtual void removeDisplay(Display*) = 0;
-	virtual void notifyDisplays() = 0;	
-	virtual ~Observable() {}
+    virtual void registerDisplays(vector<Display*>) = 0;
+	virtual ~Observable() = default;
 };
 
 /***********************************************************************/
