@@ -24,9 +24,9 @@ class OptionParser {
 public:
 	OptionParser(string, vector<string>);
     OptionParser(string, map<string, string>&);
-	~OptionParser() {}
+	~OptionParser() = default;
 	map<string, string> getParameters(); //adds inputdir to parameters if indicated
-	bool getNameFile(vector<string>);
+	
 private:
 	map<string, string> parameters;
 	MothurOut* m;
