@@ -17,7 +17,7 @@ ReadCluster::ReadCluster(string distfile, float c, string o, bool s){
 		cutoff = c;
 		outputDir = o;
 		sortWanted = s;
-		list = NULL;
+		list = nullptr;
 }
 
 /***********************************************************************/
@@ -68,16 +68,14 @@ int ReadCluster::convertPhylip2Column(NameAssignment*& nameMap){
 		//convert phylip file to column file
 		map<int, string> rowToName;
 		map<int, string>::iterator it;
-		
-		ifstream in;
-		ofstream out;
+
 		string tempFile = distFile + ".column.temp";
 		
-		util.openInputFile(distFile, in);  util.gobble(in);
-		util.openOutputFile(tempFile, out);
+        ifstream in; util.openInputFile(distFile, in);  gobble(in);
+        ofstream out; util.openOutputFile(tempFile, out);
 		
 		float distance;
-		int square, nseqs;
+        int square, nseqs; square = 0;
 		string name;
 		vector<string> matrixNames;
 		
@@ -90,7 +88,7 @@ int ReadCluster::convertPhylip2Column(NameAssignment*& nameMap){
 		rowToName[0] = name;
 		matrixNames.push_back(name);
 		
-		if(nameMap == NULL){
+		if(nameMap == nullptr){
 			list = new ListVector(nseqs);
 			list->set(0, name);
 		}
@@ -124,7 +122,7 @@ int ReadCluster::convertPhylip2Column(NameAssignment*& nameMap){
 				matrixNames.push_back(name);
 				
 				//there's A LOT of repeated code throughout this method...
-				if(nameMap == NULL){
+				if(nameMap == nullptr){
 					list->set(i, name);
 					
 					for(int j=0;j<i;j++){
@@ -165,7 +163,7 @@ int ReadCluster::convertPhylip2Column(NameAssignment*& nameMap){
 				rowToName[i] = name;
 				matrixNames.push_back(name);
 		
-				if(nameMap == NULL){
+				if(nameMap == nullptr){
 					list->set(i, name);
 					for(int j=0;j<nseqs;j++){
 						if (m->getControl_pressed()) { in.close(); out.close(); util.mothurRemove(tempFile); return 0; }
@@ -202,7 +200,7 @@ int ReadCluster::convertPhylip2Column(NameAssignment*& nameMap){
 		in.close();
 		out.close();
 	
-		if(nameMap == NULL){
+		if(nameMap == nullptr){
 			nameMap = new NameAssignment();
 			for(int i=0;i<matrixNames.size();i++){
 				nameMap->push_back(matrixNames[i]);
@@ -225,7 +223,7 @@ int ReadCluster::convertPhylip2Column(NameAssignment*& nameMap){
 			
 			in2 >> first >> second >> dist;
 			out2 << rowToName[first] << '\t' << rowToName[second] << '\t' << dist << endl;
-			util.gobble(in2);
+			gobble(in2);
 		}
 		in2.close();
 		out2.close();
@@ -249,13 +247,11 @@ int ReadCluster::convertPhylip2Column(CountTable*& ct){
 		//convert phylip file to column file
 		map<int, string> rowToName;
 		map<int, string>::iterator it;
-		
-		ifstream in;
-		ofstream out;
+
 		string tempFile = distFile + ".column.temp";
 		
-		util.openInputFile(distFile, in);  util.gobble(in);
-		util.openOutputFile(tempFile, out);
+        ifstream in; util.openInputFile(distFile, in);  gobble(in);
+        ofstream out; util.openOutputFile(tempFile, out);
 		
 		float distance;
 		int square, nseqs;
@@ -271,7 +267,7 @@ int ReadCluster::convertPhylip2Column(CountTable*& ct){
 		rowToName[0] = name;
 		matrixNames.push_back(name);
 		
-		if(ct == NULL){
+		if(ct == nullptr){
 			list = new ListVector(nseqs);
 			list->set(0, name);
 		}
@@ -302,7 +298,7 @@ int ReadCluster::convertPhylip2Column(CountTable*& ct){
 				matrixNames.push_back(name);
 				
 				//there's A LOT of repeated code throughout this method...
-				if(ct == NULL){
+				if(ct == nullptr){
 					list->set(i, name);
 					
 					for(int j=0;j<i;j++){
@@ -342,7 +338,7 @@ int ReadCluster::convertPhylip2Column(CountTable*& ct){
 				rowToName[i] = name;
 				matrixNames.push_back(name);
                 
-				if(ct == NULL){
+				if(ct == nullptr){
 					list->set(i, name);
 					for(int j=0;j<nseqs;j++){
 						if (m->getControl_pressed()) { in.close(); out.close(); util.mothurRemove(tempFile); return 0; }
@@ -377,7 +373,7 @@ int ReadCluster::convertPhylip2Column(CountTable*& ct){
 		in.close();
 		out.close();
         
-		if(ct == NULL){
+		if(ct == nullptr){
 			ct = new CountTable();
 			for(int i=0;i<matrixNames.size();i++){
 				ct->push_back(matrixNames[i]);
@@ -400,7 +396,7 @@ int ReadCluster::convertPhylip2Column(CountTable*& ct){
 			
 			in2 >> first >> second >> dist;
 			out2 << rowToName[first] << '\t' << rowToName[second] << '\t' << dist << endl;
-			util.gobble(in2);
+			gobble(in2);
 		}
 		in2.close();
 		out2.close();
