@@ -15,13 +15,14 @@
 #include "nameassignment.hpp"
 #include "counttable.h"
 #include "sparsedistancematrix.h"
+#include "utils.hpp"
 
 
 class ReadMatrix {
 
 public:
 	ReadMatrix(){ DMatrix = new SparseDistanceMatrix(); m = MothurOut::getInstance();  }
-	virtual ~ReadMatrix() {}
+	virtual ~ReadMatrix() = default;
 	virtual int read(NameAssignment*){ return 1; }
     virtual int read(CountTable*){ return 1; }
 	
@@ -37,6 +38,7 @@ protected:
 	float cutoff;
 	MothurOut* m;
 	bool sim;
+    Utils util;
 };
 
 
