@@ -10,8 +10,6 @@
 #include "refchimeratest.h"
 #include "mothur.h"
 
-int MAXINT = numeric_limits<int>::max();
-
 //***************************************************************************************************************
 
 RefChimeraTest::RefChimeraTest(vector<Sequence>& refs, bool aligned) : aligned(aligned){
@@ -128,16 +126,23 @@ int RefChimeraTest::analyzeUnalignedQuery(string queryName, string querySeq, str
     int bestRefDiffs = numeric_limits<int>::max();
     double bestRefLength = 0;
     
+   // if (queryName == "OTU_1008") {
+   //     cout << queryName << endl << querySeq << endl << endl;
+   // }
     for(int i=0;i<numRefSeqs;i++){
         double length = 0;
         double diffs = alignQueryToReferences(querySeq, referenceSeqs[i], queryAlign[i], refAlign[i], length);
         if(diffs < bestRefDiffs){
             bestRefDiffs = diffs;
             bestRefLength = length;
+            //if (queryName == "OTU_1008") {
+              //  cout << queryName << endl << queryAlign[i] << endl << endl << refAlign[i] << endl;
+            //}
             bestRefIndex = i;
         }
     }
 
+   
     if(bestRefDiffs >= 3){
         for(int i=0;i<numRefSeqs;i++){
             leftDiffs[i].assign(seqLength, 0);
@@ -250,8 +255,6 @@ int RefChimeraTest::analyzeUnalignedQuery(string queryName, string querySeq, str
 /**************************************************************************************************/
 
 double RefChimeraTest::alignQueryToReferences(string query, string reference, string& qAlign, string& rAlign, double& length){
-    
-    
     try {
 		double GAP = -5;
 		double MATCH = 1;
@@ -409,6 +412,7 @@ double RefChimeraTest::alignQueryToReferences(string query, string reference, st
             rAlign = reference.substr(0, j) + rAlign;
         }
 
+        if (length == 0) { diffs = MOTHURMAX; }
         
 		return diffs;
 	}
@@ -417,7 +421,6 @@ double RefChimeraTest::alignQueryToReferences(string query, string reference, st
 		exit(1);
 	}
 }
-
 /**************************************************************************************************/
 
 int RefChimeraTest::getUnalignedDiffs(string qAlign, string rAlign, vector<int>& leftDiffs, vector<int>& leftMap, vector<int>& rightDiffs, vector<int>& rightMap){
@@ -485,7 +488,7 @@ int RefChimeraTest::getUnalignedDiffs(string qAlign, string rAlign, vector<int>&
 
 int RefChimeraTest::getAlignedMismatches(string& querySeq, vector<vector<int> >& left, vector<vector<int> >& right, int& bestRefSeq){
 	
-	int bestSequenceMismatch = MAXINT;
+	int bestSequenceMismatch = MOTHURMAX;
 	
 	for(int i=0;i<numRefSeqs;i++){
 		
@@ -519,7 +522,7 @@ int RefChimeraTest::getAlignedMismatches(string& querySeq, vector<vector<int> >&
 
 int RefChimeraTest::getChimera(vector<vector<int> >& left, vector<vector<int> >& right, int& leftParent, int& rightParent, int& breakPoint, vector<int>& singleLeft, vector<int>& bestLeft, vector<int>& singleRight, vector<int>& bestRight){
 	
-	singleLeft.resize(alignLength, MAXINT);
+	singleLeft.resize(alignLength, MOTHURMAX);
 	bestLeft.resize(alignLength, -1);
 	
 	for(int l=0;l<alignLength;l++){
@@ -531,7 +534,7 @@ int RefChimeraTest::getChimera(vector<vector<int> >& left, vector<vector<int> >&
 		}
 	}
 	
-	singleRight.resize(alignLength, MAXINT);
+	singleRight.resize(alignLength, MOTHURMAX);
 	bestRight.resize(alignLength, -1);
 	
 	for(int l=0;l<alignLength;l++){
@@ -543,7 +546,7 @@ int RefChimeraTest::getChimera(vector<vector<int> >& left, vector<vector<int> >&
 		}
 	}
 	
-	int bestChimeraMismatches = MAXINT;
+	int bestChimeraMismatches = MOTHURMAX;
 	leftParent = -1;
 	rightParent = -1;
 	breakPoint = -1;
@@ -565,7 +568,7 @@ int RefChimeraTest::getChimera(vector<vector<int> >& left, vector<vector<int> >&
 
 int RefChimeraTest::getTrimera(vector<vector<int> >& left, vector<vector<int> >& right, int& leftParent, int& middleParent, int& rightParent, int& breakPointA, int& breakPointB, vector<int>& singleLeft, vector<int>& bestLeft, vector<int>& singleRight, vector<int>& bestRight){
 	
-	int bestTrimeraMismatches = MAXINT;
+	int bestTrimeraMismatches = MOTHURMAX;
 	
 	leftParent = -1;
 	middleParent = -1;
@@ -578,7 +581,7 @@ int RefChimeraTest::getTrimera(vector<vector<int> >& left, vector<vector<int> >&
     vector<vector<int> > minDeltaSeq; minDeltaSeq.resize(alignLength);
 	
 	for(int i=0;i<alignLength;i++){
-		minDelta[i].assign(alignLength, MAXINT);
+		minDelta[i].assign(alignLength, MOTHURMAX);
 		minDeltaSeq[i].assign(alignLength, -1);
 	}
 	
