@@ -20,7 +20,7 @@ public:
 	~Venn(){};
 
 	vector<string> getPic(SAbundVector*, vector<Calculator*>);
-	vector<string> getPic(vector<SharedRAbundVector*>, vector<Calculator*>);
+	vector<string> getPic(vector<SharedRAbundVector*>, vector<Calculator*>, vector<string>);
 
 private:
 	Calculator* singleCalc;
